@@ -1,22 +1,22 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module implement the EFA (Evolving Factor Analysis) class.
 """
 from datetime import datetime, timezone
 
 import numpy as np
-from traitlets import HasTraits, Instance, Float
+from traitlets import Float, HasTraits, Instance
 
-from spectrochempy.core.dataset.nddataset import NDDataset
-from spectrochempy.core.dataset.coordset import CoordSet
+from spectrochempy.analysis.svd import SVD
 from spectrochempy.core.dataset.coord import Coord
+from spectrochempy.core.dataset.coordset import CoordSet
+from spectrochempy.core.dataset.nddataset import NDDataset
 from spectrochempy.utils import MASKED
-from .svd import SVD
 
 __all__ = ["EFA"]
 
