@@ -1,29 +1,29 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 Module to perform fitting of 1D or n-D spectral data.
 """
-__all__ = ["Fit", "optimize", "FitParameters", "ParameterScript"]
+__all__ = ["Fit", "FitParameters", "ParameterScript"]
 
 __dataset_methods__ = []
 
-import sys
 import re
+import sys
 from collections import UserDict
 from warnings import warn
 
 import numpy as np
 import scipy.optimize
-from traitlets import HasTraits, Bool, Any, Unicode, Instance, List, observe
 from IPython import display
+from traitlets import Any, Bool, HasTraits, Instance, List, Unicode, observe
 
-from spectrochempy.utils import htmldoc
-from spectrochempy.core import preferences, info_, warning_, INFO
 from spectrochempy.analysis import models as models_
+from spectrochempy.core import INFO, info_, preferences, warning_
+from spectrochempy.utils import htmldoc
 
 
 # ======================================================================================================================
@@ -153,8 +153,6 @@ class FitParameters(UserDict):
 
     # ------------------------------------------------------------------------
     def __str__(self):
-
-        # .............................................................
         def makestr(key):
 
             keystring = key.split("_")[0]
@@ -175,8 +173,6 @@ class FitParameters(UserDict):
 
                 return f"{keystring}: {float(val):10.4f}, {lob}, {upb}\n"
 
-        # ..............................................................
-
         message = "#PARAMETER SCRIPT\n\nCOMMON:\n"
 
         var = ""
