@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module implements the MCRALS class.
 """
@@ -12,14 +12,15 @@ __all__ = ["MCRALS"]
 
 __dataset_methods__ = []
 
-import numpy as np
-from traitlets import HasTraits, Instance, Dict, Unicode
 import warnings
 
-from spectrochempy.core.dataset.nddataset import NDDataset
+import numpy as np
+from traitlets import Dict, HasTraits, Instance, Unicode
+
 from spectrochempy.analysis.pca import PCA
-from spectrochempy.core.dataset.npy import dot
-from spectrochempy.core import info_, set_loglevel, INFO
+from spectrochempy.core import INFO, info_, set_loglevel
+from spectrochempy.core.dataset.arraymixins.npy import dot
+from spectrochempy.core.dataset.nddataset import NDDataset
 from spectrochempy.utils.exceptions import deprecated
 
 
@@ -363,14 +364,18 @@ class MCRALS(HasTraits):
             C.set_coordset(y=cy, x=cx)
 
         change = tol + 1
-        stdev = X.std()
+        stdev = np.std(X.data)
         niter = 0
         ndiv = 0
 
-        log = "*** ALS optimisation log***\n"
-        log += "#iter     Error/PCA        Error/Exp      %change \n"
-        log += "------------------------------------------------- \n"
+        log = "*** ALS optimisation log*** \n"
         info_(log)
+        logentry = "#iter     RSE / PCA        RSE / Exp      %change \n"
+        log += logentry
+        info_(logentry)
+        logentry = "------------------------------------------------- \n"
+        log += logentry
+        info_(logentry)
 
         while change >= tol and niter < maxit and ndiv < maxdiv:
 
@@ -479,11 +484,11 @@ class MCRALS(HasTraits):
             # compute residuals
             # -----------------
             X_hat = dot(C, St)
-            stdev2 = (X_hat - X.data).std()
+            stdev2 = np.std(X_hat.data - X.data)
             change = 100 * (stdev2 - stdev) / stdev
             stdev = stdev2
 
-            stdev_PCA = (X_hat - Xpca.data).std()  #
+            stdev_PCA = np.std(X_hat.data - Xpca.data)  #
 
             logentry = "{:3d}      {:10f}      {:10f}      {:10f}".format(
                 niter, stdev_PCA, stdev2, change
