@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module implement the PCA (Principal Component Analysis) class.
 """
@@ -18,13 +18,12 @@ from matplotlib.ticker import MaxNLocator, ScalarFormatter
 from scipy import special
 from traitlets import HasTraits, Instance
 
-from spectrochempy.core import info_
 from spectrochempy.analysis.svd import SVD
+from spectrochempy.core import info_
+from spectrochempy.core.dataset.arraymixins.npy import dot
 from spectrochempy.core.dataset.coord import Coord
 from spectrochempy.core.dataset.nddataset import NDDataset
-from spectrochempy.core.dataset.npy import dot
-from spectrochempy.utils import NRed, NBlue
-
+from spectrochempy.utils import NBlue, NRed
 
 # ======================================================================================================================
 # class PCA
@@ -88,7 +87,6 @@ class PCA(HasTraits):
     _ev_cum = Instance(NDDataset)
     """|NDDataset| - Cumulative Explained Variances."""
 
-    # ..........................................................................
     def __init__(self, dataset, centered=True, standardized=False, scaled=False):
 
         super().__init__()
