@@ -1,12 +1,9 @@
 # -*- coding: utf-8 -*-
-
-#
-# =============================================================================
-# Copyright (©) 2015-2022 LCS
-# Laboratoire Catalyse et Spectrochimie, Caen, France.
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
 # CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
-# See full LICENSE agreement in the root directory
-# =============================================================================
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module implement the SIMPLISMA class.
 """
@@ -15,18 +12,17 @@ __all__ = ["SIMPLISMA"]
 
 __dataset_methods__ = []
 
+import warnings
+
 # ----------------------------------------------------------------------------
 # imports
 # ----------------------------------------------------------------------------
 import numpy as np
-
-import warnings
 from traitlets import HasTraits, Instance, Unicode
 
+from spectrochempy.core import INFO, info_, set_loglevel
+from spectrochempy.core.dataset.arraymixins.npy import dot
 from spectrochempy.core.dataset.nddataset import NDDataset
-from spectrochempy.core.dataset.npy import dot
-from spectrochempy.core import info_, set_loglevel, INFO
-
 
 # ============================================================================
 # class SIMPLISMA
@@ -60,8 +56,6 @@ class SIMPLISMA(HasTraits):
     noise : float or int, optional, default=5
         A correction factor (%) for low intensity variables (0 - no offset,
         15 - large offset).
-    verbose : bool, optional, default=True
-        If True some information is given during the analysis.
     """
 
     _St = Instance(NDDataset)
@@ -117,8 +111,11 @@ class SIMPLISMA(HasTraits):
             warnings.warn("SIMPLISMA does not handle easily negative values.")
             # TODO: check whether negative values should be set to zero or not.
 
-        verbose = kwargs.get("verbose", True)
-        if verbose:
+        if "verbose" in kwargs.keys():
+            warnings.warn(
+                "verbose deprecated. Instead, use set_loglevel(INFO) before launching MCRALS",
+                DeprecationWarning,
+            )
             set_loglevel(INFO)
 
         interactive = kwargs.get("interactive", False)
@@ -190,11 +187,11 @@ class SIMPLISMA(HasTraits):
         sigma = np.std(X.data, axis=0)
         mu = np.mean(X.data, axis=0)
         alpha = (noise / 100) * np.max(mu.data)
-        lamda = np.sqrt(mu ** 2 + sigma ** 2)
+        lamda = np.sqrt(mu**2 + sigma**2)
         p = sigma / (mu + alpha)
 
         # scale dataset
-        Xscaled = X.data / np.sqrt(mu ** 2 + (sigma + alpha) ** 2)
+        Xscaled = X.data / np.sqrt(mu**2 + (sigma + alpha) ** 2)
 
         # COO dispersion matrix
         COO = (1 / X.shape[-2]) * np.dot(Xscaled.T, Xscaled)
@@ -205,7 +202,7 @@ class SIMPLISMA(HasTraits):
         while not finished:
             # compute first purest variable and weights
             if j == 0:
-                w[j, :] = lamda ** 2 / (mu ** 2 + (sigma + alpha) ** 2)
+                w[j, :] = lamda**2 / (mu**2 + (sigma + alpha) ** 2)
                 s[j, :] = sigma * w[j, :]
                 Pt[j, :] = p * w[j, :]
 
@@ -222,7 +219,7 @@ class SIMPLISMA(HasTraits):
                 )
                 logs += llog + "\n"
 
-                if verbose or interactive:
+                if interactive:
                     print(llog)
 
                 if interactive:
@@ -303,7 +300,7 @@ class SIMPLISMA(HasTraits):
                 )
                 logs += llog + "\n"
 
-                if verbose or interactive:
+                if interactive:
                     info_(llog)
 
                 if (
