@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-# Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root
-# directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 Application Programming Interface.
+
+isort:skip_file
 """
 
 # During the initialization of this package, a `matplotlib` backend is set
@@ -86,8 +87,8 @@ ALL = ["NO_DISPLAY", "NO_DIALOG"]
 # Now we can start loading the API
 # ------------------------------------------------------------------
 # import the core api
-from . import core
-from .core import *  # noqa: F403, F401, E402
+from spectrochempy import core
+from spectrochempy.core import *  # noqa: F403, F401, E402
 
 ALL += core.__all__
 
@@ -118,7 +119,7 @@ if IN_IPYTHON and KERNEL and not NO_DISPLAY:  # pragma: no cover
         IP.magic("matplotlib qt")
 
 # a useful utilities for dealing with path
-from .utils import pathclean
+from spectrochempy.utils import pathclean
 
 DATADIR = pathclean(preferences.datadir)
 
