@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module defines the `application` on which the API rely.
 
@@ -11,54 +11,54 @@ It also defines
 the default application preferences and IPython magic functions.
 """
 
-__all__ = []
-
-import sys
+import json
 import logging
-from logging.handlers import RotatingFileHandler
-import subprocess
-import warnings
 import pprint
+import subprocess
+import sys
+import threading
+import time
+import warnings
+from datetime import date, timedelta
 from os import environ
 from pathlib import Path
-import threading
-import json
-from pkg_resources import parse_version, get_distribution, DistributionNotFound
-import requests
-from setuptools_scm import get_version
-from datetime import date, timedelta
 
+import matplotlib as mpl
 import numpy as np
-
-from traitlets.config.configurable import Config
-from traitlets.config.application import Application
+import requests
+from IPython import get_ipython
+from IPython.core.error import UsageError
+from IPython.core.interactiveshell import InteractiveShell
+from IPython.core.magic import Magics, line_cell_magic, magics_class
+from IPython.core.magics.code import extract_symbols
+from IPython.display import clear_output, publish_display_data
+from IPython.utils.text import get_text_list
+from jinja2 import Template
+from matplotlib import pyplot as plt
+from pkg_resources import DistributionNotFound, get_distribution, parse_version
+from setuptools_scm import get_version
 from traitlets import (
     Bool,
-    Unicode,
-    List,
-    Integer,
     Enum,
-    Union,
     HasTraits,
     Instance,
+    Integer,
+    List,
+    Unicode,
+    Union,
     default,
     observe,
     validate,
 )
+from traitlets.config.application import Application
+from traitlets.config.configurable import Config
 from traitlets.config.manager import BaseJSONConfigManager
-import matplotlib as mpl
-from matplotlib import pyplot as plt
-from IPython import get_ipython
-from IPython.core.interactiveshell import InteractiveShell
-from IPython.core.magic import Magics, magics_class, line_cell_magic
-from IPython.core.magics.code import extract_symbols
-from IPython.core.error import UsageError
-from IPython.utils.text import get_text_list
-from IPython.display import publish_display_data, clear_output
-from jinja2 import Template
 
-from spectrochempy.utils import MetaConfigurable, pathclean, get_pkg_path, Version
 from spectrochempy.plot_preferences import PlotPreferences
+from spectrochempy.utils.file import pathclean
+from spectrochempy.utils.packages import get_pkg_path
+from spectrochempy.utils.traits import MetaConfigurable
+from spectrochempy.utils.version import Version
 
 # set the default style
 plt.style.use(["classic"])
@@ -161,7 +161,6 @@ except LookupError:  # pragma: no cover
     __version__ = __release__
 
 
-# ............................................................................
 def _get_copyright():
     current_year = np.datetime64("now", "Y")
     right = f"2014-{current_year}"
@@ -173,7 +172,6 @@ __copyright__ = _get_copyright()
 "Copyright string of this package"
 
 
-# .............................................................................
 def _get_release_date():
     return subprocess.getoutput("git log -1 --tags --date=short --format='%ad'")
 
@@ -187,12 +185,23 @@ def _get_pypi_version():
     Get the last released pypi version
     """
     url = "https://pypi.python.org/pypi/spectrochempy/json"
-    try:
-        response = requests.get(url)
-        if response.status_code != 200:
-            return
-    except requests.exceptions.RequestException:  # pragma: no cover
-        return
+
+    connection_timeout = 30  # secondss
+    start_time = time.time()
+    while True:
+        try:
+            response = requests.get(url)
+            if response.status_code != 200:
+                return
+            break  # exit the while loop in case of success
+
+        except (ConnectionError, requests.exceptions.RequestException):
+            if time.time() > start_time + connection_timeout:
+                # 'Unable to get updates after {} seconds of ConnectionErrors'
+                return
+            else:
+                time.sleep(1)  # attempting once every second
+
     releases = json.loads(response.text)["releases"]
     versions = sorted(releases, key=parse_version)
     last_version = versions[-1]
@@ -205,10 +214,11 @@ def _get_pypi_version():
 def _check_for_updates(*args):
 
     old = Version(__version__)
-    version, release_date = _get_pypi_version()
-    # conda_versions = _get_conda_package_version()
-    if version is None:
-        # probably no connection
+    res = _get_pypi_version()
+    if res is not None:
+        version, release_date = res
+    else:
+        # probably a ConnectionError
         return
 
     new_release = None
@@ -267,7 +277,7 @@ CHECK_UPDATE = threading.Thread(target=_check_for_updates, args=(1,))
 CHECK_UPDATE.start()
 
 # other info
-# ............................................................................
+
 
 __url__ = "https://www.spectrochempy.fr"
 "URL for the documentation of this package"
@@ -289,7 +299,9 @@ __cite__ = (
 "How to cite this package"
 
 
-# ..........................................................................
+# Directories
+
+
 def _find_or_create_spectrochempy_dir():
     directory = Path.home() / ".spectrochempy"
 
@@ -302,6 +314,53 @@ def _find_or_create_spectrochempy_dir():
     return directory
 
 
+def get_config_dir():
+    """
+    Determines the SpectroChemPy configuration directory name and
+    creates the directory if it doesn't exist.
+
+    This directory is typically ``$HOME/.spectrochempy/config``,
+    but if the
+    SCP_CONFIG_HOME environment variable is set and the
+    ``$SCP_CONFIG_HOME`` directory exists, it will be that
+    directory.
+
+    If neither exists, the former will be created.
+
+    Returns
+    -------
+    config_dir : str
+        The absolute path to the configuration directory.
+    """
+
+    # first look for SCP_CONFIG_HOME
+    scp = environ.get("SCP_CONFIG_HOME")
+
+    if scp is not None and Path(scp).exists():
+        return Path(scp)
+
+    config = _find_or_create_spectrochempy_dir() / "config"
+    if not config.exists():
+        config.mkdir(exist_ok=True)
+
+    return config
+
+
+def get_log_dir():
+
+    # first look for SCP_LOGS
+    logdir = environ.get("SCP_LOGS")
+
+    if logdir is not None and Path(logdir).exists():
+        return Path(logdir)
+
+    logdir = _find_or_create_spectrochempy_dir() / "logs"
+    if not logdir.exists():
+        logdir.mkdir(exist_ok=True)
+
+    return logdir
+
+
 # ======================================================================================================================
 # Magic ipython function
 # ======================================================================================================================
@@ -610,24 +669,20 @@ class GeneralPreferences(MetaConfigurable):
 
         return pscp
 
-    # ..........................................................................
     @default("workspace")
     def _get_workspace_default(self):
         # the spectra path in package data
         return Path.home()
 
-    # ..........................................................................
     @default("databases_directory")
     def _get_databases_directory_default(self):
         # the spectra path in package data
         return pathclean(get_pkg_path("databases", "scp_data"))
 
-    # ..........................................................................
     @default("datadir")
     def _get_default_datadir(self):
         return pathclean(self.parent.datadir.path)
 
-    # ..........................................................................
     @observe("datadir")
     def _datadir_changed(self, change):
         self.parent.datadir.path = pathclean(change["new"])
@@ -640,7 +695,6 @@ class GeneralPreferences(MetaConfigurable):
             datadir = pathclean(datadir)
         return datadir
 
-    # ..........................................................................
     @property
     def log_level(self):
         """
@@ -648,7 +702,6 @@ class GeneralPreferences(MetaConfigurable):
         """
         return self.parent.log_level
 
-    # ..........................................................................
     @log_level.setter
     def log_level(self, value):
         if isinstance(value, str):
@@ -661,7 +714,6 @@ class GeneralPreferences(MetaConfigurable):
                 )
         self.parent.log_level = value
 
-    # ..........................................................................
     def __init__(self, **kwargs):
         super().__init__(jsonfile="GeneralPreferences", **kwargs)
 
@@ -741,7 +793,7 @@ you are kindly requested to cite it this way: <pre>{__cite__}</pre></p>.
 
     @default("config_dir")
     def _get_config_dir_default(self):
-        return self.get_config_dir()
+        return get_config_dir()
 
     config_manager = Instance(BaseJSONConfigManager)
 
@@ -749,11 +801,6 @@ you are kindly requested to cite it this way: <pre>{__cite__}</pre></p>.
     def _get_default_config_manager(self):
         return BaseJSONConfigManager(config_dir=str(self.config_dir))
 
-    log_format = Unicode(
-        "%(highlevel)s %(message)s",
-        help="The Logging format template",
-    ).tag(config=True)
-
     debug = Bool(True, help="Set DEBUG mode, with full outputs").tag(config=True)
     """Flag to set debugging mode."""
 
@@ -798,6 +845,32 @@ you are kindly requested to cite it this way: <pre>{__cite__}</pre></p>.
     port = Integer(7000, help="Dash server port").tag(config=True)
     """Dash server port."""
 
+    # logger
+    log_format = Unicode(
+        "%(highlevel)s %(message)s",
+        help="The Logging format template",
+    ).tag(config=True)
+
+    logging_config = {
+        "handlers": {
+            "rotatingfile": {
+                "class": "logging.handlers.RotatingFileHandler",
+                "level": "DEBUG",
+                "filename": str(get_log_dir() / "spectrochempy.log"),
+                "maxBytes": 32768,
+                "backupCount": 5,
+            }
+        },
+        "loggers": {
+            "SpectroChemPy": {
+                "level": "DEBUG",
+                # NOTE: if you don't list the default "console"
+                # handler here then it will be disabled
+                "handlers": ["console", "rotatingfile"],
+            },
+        },
+    }
+
     # Command line interface
     # ------------------------------------------------------------------------
 
@@ -862,25 +935,6 @@ you are kindly requested to cite it this way: <pre>{__cite__}</pre></p>.
     def __init__(self, **kwargs):
 
         super().__init__(**kwargs)
-
-        self.logs = (
-            self.log
-        )  # we change the no name in order to avoid latter conflict with numpy.log
-
-        self.logs.setLevel(0)  # reset to NOTSET
-
-        # Set a log filehandler
-        logdir = self.get_config_dir().parent / "logs"
-        logdir.mkdir(exist_ok=True)
-        rh = RotatingFileHandler(
-            str(logdir / "spectrochempy.log"), maxBytes=32 * 1024, backupCount=5
-        )
-        rh.setLevel(INFO)
-        rh.setFormatter(logging.Formatter("%(message)s"))
-        self.logs.addHandler(rh)
-
-        self.log.info("started")
-
         self.initialize()
 
     def initialize(self, argv=None):
@@ -937,7 +991,7 @@ you are kindly requested to cite it this way: <pre>{__cite__}</pre></p>.
         # warning handler
         # --------------------------------------------------------------------
         def send_warnings_to_log(message, category):
-            self.logs.warning(f"{category.__name__} - {message}")
+            self.log.warning(f"{category.__name__} - {message}")
 
         warnings.showwarning = send_warnings_to_log
 
@@ -953,7 +1007,7 @@ you are kindly requested to cite it this way: <pre>{__cite__}</pre></p>.
                 if self.log_level == logging.DEBUG:
                     shell.showtraceback((etype, evalue, tb), tb_offset=tb_offset)
                 else:
-                    self.logs.error(f"{etype.__name__}: {evalue}")
+                    self.log.error(f"{etype.__name__}: {evalue}")
 
             ipy.set_custom_exc((Exception,), _custom_exc)
 
@@ -1000,39 +1054,6 @@ you are kindly requested to cite it this way: <pre>{__cite__}</pre></p>.
         self.preferences = GeneralPreferences(config=self.config, parent=self)
         self.plot_preferences = PlotPreferences(config=self.config, parent=self)
 
-    # ..........................................................................
-    @staticmethod
-    def get_config_dir():
-        """
-        Determines the SpectroChemPy configuration directory name and
-        creates the directory if it doesn't exist.
-
-        This directory is typically ``$HOME/.spectrochempy/config``,
-        but if the
-        SCP_CONFIG_HOME environment variable is set and the
-        ``$SCP_CONFIG_HOME`` directory exists, it will be that
-        directory.
-
-        If neither exists, the former will be created.
-
-        Returns
-        -------
-        config_dir : str
-            The absolute path to the configuration directory.
-        """
-
-        # first look for SCP_CONFIG_HOME
-        scp = environ.get("SCP_CONFIG_HOME")
-
-        if scp is not None and Path(scp).exists():
-            return Path(scp)
-
-        config = _find_or_create_spectrochempy_dir() / "config"
-        if not config.exists():
-            config.mkdir(exist_ok=True)
-
-        return config
-
     def start_show_config(self):
         """
         Start function used when show_config is True.
@@ -1139,10 +1160,9 @@ you are kindly requested to cite it this way: <pre>{__cite__}</pre></p>.
         if msg:
             self.log.warning(msg)
 
-        self.logs.info("\n\nAPI loaded - application is ready")
+        self.log.info("\n\nAPI loaded - application is ready")
         return True
 
-    # ..........................................................................
     def _make_default_config_file(self):
         """auto generate default config file."""
 
@@ -1151,7 +1171,7 @@ you are kindly requested to cite it this way: <pre>{__cite__}</pre></p>.
 
         if not fname.exists() or self.reset_config:
             sfil = self.generate_config_file()
-            self.logs.info(f"Generating default config file: {fname}")
+            self.log.info(f"Generating default config file: {fname}")
             with open(fname, "w") as fil:
                 fil.write(sfil)
 
@@ -1163,16 +1183,11 @@ you are kindly requested to cite it this way: <pre>{__cite__}</pre></p>.
     def _log_level_changed(self, change):
 
         # log file
-        if change.new == DEBUG:
-            self.logs.handlers[0].setLevel(INFO)  # no debug in the stdout
-            self.logs.handlers[1].setLevel(DEBUG)
-        else:
-            self.logs.handlers[0].setLevel(change.new)
-            self.logs.handlers[1].setLevel(change.new)
+        self.log.setLevel(change.new)
+        self.log.handlers[0].setLevel(change.new)
+        self.log.handlers[1].setLevel(DEBUG)
 
-        # root
-        self.logs.setLevel(DEBUG)  # reset to DEBUG
-        self.logs.info(
+        self.log.info(
             f"changed default log_level to {logging.getLevelName(change.new)}"
         )
 
