@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module implements the class |Coord|.
 """
@@ -14,29 +14,15 @@ import copy as cpy
 import textwrap
 
 import numpy as np
-from traitlets import (
-    Bool,
-    observe,
-    All,
-    Unicode,
-    Integer,
-    Union,
-    CFloat,
-    CInt,
-    Instance,
-)
+from traitlets import All, Bool, CFloat, CInt, Instance, Integer, Unicode, Union
 from traitlets import default as traitdefault
+from traitlets import observe
 
-from spectrochempy.core.dataset.ndarray import NDArray
-from spectrochempy.core.dataset.ndmath import NDMath, _set_operators
-from spectrochempy.utils import (
-    colored_output,
-    NOMASK,
-    INPLACE,
-    spacing_,
-)
-from spectrochempy.core.units import Quantity, ur
 from spectrochempy.core import error_
+from spectrochempy.core.dataset.arraymixins.ndmath import NDMath, _set_operators
+from spectrochempy.core.dataset.basearrays.ndarray import NDArray
+from spectrochempy.core.units import Quantity, ur
+from spectrochempy.utils import INPLACE, NOMASK, colored_output, spacing_
 
 
 # ======================================================================================================================
@@ -103,9 +89,6 @@ class Coord(NDMath, NDArray):
         It is optional but recommended to give a title to each ndarray.
     dlabel :  str, optional
         Alias of `title`.
-    meta : dict-like object, optional
-        Additional metadata for this object. Must be dict-like but no
-        further restriction is placed on meta.
     copy : bool, optional
         Perform a copy of the passed object. Default is False.
     linear : bool, optional
@@ -128,16 +111,19 @@ class Coord(NDMath, NDArray):
     --------
 
     We first import the object from the api :
+
     >>> from spectrochempy import Coord
 
     We then create a numpy |ndarray| and use it as the numerical `data`
-    axis of our new |Coord| object.
+    axis of our new |Coord| object :
+
     >>> c0 = Coord.arange(1., 12., 2., title='frequency', units='Hz')
     >>> c0
     Coord: [float64] Hz (size: 6)
 
     We can take a series of str to create a non numerical but labelled
     axis :
+
     >>> tarr = list('abcdef')
     >>> tarr
     ['a', 'b', 'c', 'd', 'e', 'f']
@@ -178,7 +164,6 @@ class Coord(NDMath, NDArray):
     # readonly property
     # ------------------------------------------------------------------------
 
-    # ..........................................................................
     @property
     def reversed(self):
         """bool - Whether the axis is reversed (readonly
@@ -226,12 +211,10 @@ class Coord(NDMath, NDArray):
 
     # NDarray methods
 
-    # ..........................................................................
     @property
     def is_complex(self):
         return False  # always real
 
-    # ..........................................................................
     @property
     def is_empty(self):
         """
@@ -243,7 +226,6 @@ class Coord(NDMath, NDArray):
 
         return False
 
-    # ..........................................................................
     @property
     def ndim(self):
         if self.linear:
@@ -253,17 +235,14 @@ class Coord(NDMath, NDArray):
             raise ValueError("Coordinate's array should be 1-dimensional!")
         return ndim
 
-    # ..........................................................................
     @property
     def T(self):  # no transpose
         return self
 
-    # ..........................................................................
     # @property
     # def values(self):
     #    return super().values
 
-    # ..........................................................................
     def to(self, other, inplace=False, force=False):
 
         new = super().to(other, force=force)
@@ -284,17 +263,14 @@ class Coord(NDMath, NDArray):
 
     to.__doc__ = NDArray.to.__doc__
 
-    # ..........................................................................
     @property
     def masked_data(self):
         return super().masked_data
 
-    # ..........................................................................
     @property
     def is_masked(self):
         return False
 
-    # ..........................................................................
     @property
     def linear(self):
         """
@@ -311,7 +287,6 @@ class Coord(NDMath, NDArray):
 
         # if val and self._data is not None:  #     # linearisation of the data, if possible  #     self._linearize()
 
-    # ..........................................................................
     @property
     def offset(self):
         """
@@ -319,7 +294,6 @@ class Coord(NDMath, NDArray):
         """
         return self._offset
 
-    # ..........................................................................
     @offset.setter
     def offset(self, val):
         if isinstance(val, Quantity):
@@ -331,7 +305,6 @@ class Coord(NDMath, NDArray):
                 val = val.m
         self._offset = val
 
-    # ..........................................................................
     @property
     def offset_value(self):
         offset = self.offset
@@ -340,12 +313,10 @@ class Coord(NDMath, NDArray):
         else:
             return offset
 
-    # ..........................................................................
     @property
     def mask(self):
         return NOMASK
 
-    # ..........................................................................
     @mask.setter
     def mask(self, val):
         # Coordinates cannot be masked. Set mask always to NOMASK
@@ -353,23 +324,18 @@ class Coord(NDMath, NDArray):
 
     # NDmath methods
 
-    # ..........................................................................
     def cumsum(self, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def mean(self, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def pipe(self, func=None, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def remove_masks(self, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     @property
     def size(self):
         """
@@ -382,30 +348,24 @@ class Coord(NDMath, NDArray):
         else:
             return super().size
 
-    # ..........................................................................
     @property
     def shape(self):
         if self.linear:
             return (self._size,)
         return super().shape
 
-    # ..........................................................................
     def std(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def sum(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def swapdims(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def swapaxes(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     @property
     def spacing(self):
         """
@@ -418,111 +378,84 @@ class Coord(NDMath, NDArray):
             return self.increment * self.units
         return spacing_(self.data) * self.units
 
-    # ..........................................................................
     def squeeze(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def random(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def empty(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def empty_like(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def var(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def ones(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def ones_like(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def full(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def diag(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def diagonal(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def full_like(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def identity(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def eye(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def zeros(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def zeros_like(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def coordmin(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def coordmax(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def conjugate(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def conj(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def abs(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def absolute(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def all(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def any(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def argmax(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def argmin(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def asfortranarray(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def astype(self, dtype=None, **kwargs):
         """
         Cast the data to a specified type.
@@ -539,24 +472,19 @@ class Coord(NDMath, NDArray):
             self._offset = np.array(self._offset).astype(dtype, **kwargs)[()]
         return self
 
-    # ..........................................................................
     def average(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def clip(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     def get_axis(self, *args, **kwargs):
         return super().get_axis(*args, **kwargs)
 
-    # ..........................................................................
     @property
     def origin(self, *args, **kwargs):
         raise NotImplementedError
 
-    # ..........................................................................
     @property
     def author(self):
         return None
@@ -565,17 +493,14 @@ class Coord(NDMath, NDArray):
     def descendant(self):
         return (self.data[-1] - self.data[0]) < 0
 
-    # ..........................................................................
     @property
     def dims(self):
         return ["x"]
 
-    # ..........................................................................
     @property
     def is_1d(self):
         return True
 
-    # ..........................................................................
     def transpose(self, **kwargs):
         return self
 
@@ -608,19 +533,17 @@ class Coord(NDMath, NDArray):
     # ------------------------------------------------------------------------
     # special methods
     # ------------------------------------------------------------------------
-    # ..........................................................................
+
     def __copy__(self):
         res = self.copy(deep=False)  # we keep name of the coordinate by default
         res.name = self.name
         return res
 
-    # ..........................................................................
     def __deepcopy__(self, memo=None):
         res = self.copy(deep=True, memo=memo)
         res.name = self.name
         return res
 
-    # ..........................................................................
     def __dir__(self):
         # remove some methods with respect to the full NDArray
         # as they are not useful for Coord.
@@ -628,7 +551,6 @@ class Coord(NDMath, NDArray):
             "data",
             "labels",
             "units",
-            "meta",
             "title",
             "name",
             "offset",
@@ -637,7 +559,6 @@ class Coord(NDMath, NDArray):
             "roi",
         ]
 
-    # ..........................................................................
     def __getitem__(self, items, **kwargs):
 
         if isinstance(items, list):
@@ -704,7 +625,6 @@ class Coord(NDMath, NDArray):
         new.name = self.name
         return new
 
-    # ..........................................................................
     def __setitem__(self, items, value):
 
         if self.linear:
@@ -713,11 +633,9 @@ class Coord(NDMath, NDArray):
 
         super().__setitem__(items, value)
 
-    # ..........................................................................
     def __str__(self):
         return repr(self)
 
-    # ..........................................................................
     def _cstr(self, header="  coordinates: ... \n", print_size=True, **kwargs):
 
         indent = kwargs.get("indent", 0)
@@ -755,7 +673,6 @@ class Coord(NDMath, NDArray):
         else:
             return out
 
-    # ..........................................................................
     def __repr__(self):
         out = self._repr_value().rstrip()
         return out
@@ -764,12 +681,10 @@ class Coord(NDMath, NDArray):
     # Private properties and methods
     # ------------------------------------------------------------------------
 
-    # ..........................................................................
     @traitdefault("_increment")
     def _increment_default(self):
         return 1.0
 
-    # ..........................................................................
     def _linearize(self):
 
         if not self.linear or self._data is None:
@@ -800,12 +715,10 @@ class Coord(NDMath, NDArray):
         else:
             self._linear = False
 
-    # ..........................................................................
     @traitdefault("_offset")
     def _offset_default(self):
         return 0
 
-    # ..........................................................................
     def _set_data(self, data):
 
         if data is None:
@@ -827,10 +740,6 @@ class Coord(NDMath, NDArray):
                 except AttributeError:
                     # some attribute of NDDataset are missing in NDArray
                     pass
-            try:
-                self.history = f"Copied from object:{data.name}"
-            except AttributeError:
-                pass
 
         elif isinstance(data, NDArray):
             # init data with data from another NDArray or NDArray's subclass
@@ -846,10 +755,6 @@ class Coord(NDMath, NDArray):
                 except AttributeError:
                     # some attribute of NDDataset are missing in NDArray
                     pass
-            try:
-                self.history = f"Copied from object:{data.name}"
-            except AttributeError:
-                pass
 
         elif isinstance(data, Quantity):
             self._data = np.array(data.magnitude, subok=True, copy=self._copy)
@@ -918,7 +823,7 @@ class Coord(NDMath, NDArray):
     # ------------------------------------------------------------------------
     # Events
     # ------------------------------------------------------------------------
-    # ..........................................................................
+
     @observe(All)
     def _anytrait_changed(self, change):
         # ex: change {
@@ -935,7 +840,6 @@ class Coord(NDMath, NDArray):
                 self._linearize()
             return
 
-    # ..........................................................................
     @property
     def increment(self):
         return self._increment
@@ -993,11 +897,11 @@ class LinearCoord(Coord):
     dims : list of chars, optional.
         if specified the list must have a length equal to the number od
         data dimensions (ndim) and the chars must be
-        taken among among x,y,z,u,v,w or t. If not specified,
+        taken among x,y,z,u,v,w or t. If not specified,
         the dimension names are automatically attributed in
         this order.
     name : str, optional
-        A user friendly name for this object. If not given,
+        A user-friendly name for this object. If not given,
         the automatic `id` given at the object creation will be
         used as a name.
     labels : array of objects, optional
@@ -1075,12 +979,10 @@ class LinearCoord(Coord):
             self.increment = increment
             self._linear = True
 
-    # ..........................................................................
     @property  # read only
     def linear(self):
         return self._linear
 
-    # ..........................................................................
     def __dir__(self):
         # remove some methods with respect to the full NDArray
         # as they are not useful for Coord.
