@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module implements class |CoordSet|.
 """
@@ -11,30 +11,30 @@ This module implements class |CoordSet|.
 __all__ = ["CoordSet"]
 
 import copy as cpy
-import warnings
 import uuid
+import warnings
 
 import numpy as np
 from traitlets import (
-    HasTraits,
-    List,
-    Bool,
-    Unicode,
-    observe,
     All,
-    validate,
-    default,
+    Bool,
     Dict,
+    HasTraits,
     Int,
+    List,
+    Unicode,
+    default,
+    observe,
+    validate,
 )
 
-from spectrochempy.core.dataset.ndarray import NDArray, DEFAULT_DIM_NAME
+from spectrochempy.core.dataset.basearrays.ndarray import DEFAULT_DIM_NAME, NDArray
 from spectrochempy.core.dataset.coord import Coord, LinearCoord
 from spectrochempy.utils import (
-    is_sequence,
+    SpectroChemPyWarning,
     colored_output,
     convert_to_html,
-    SpectroChemPyWarning,
+    is_sequence,
 )
 
 
@@ -130,7 +130,7 @@ class CoordSet(HasTraits):
     # ------------------------------------------------------------------------
     # initialization
     # ------------------------------------------------------------------------
-    # ..........................................................................
+
     def __init__(self, *coords, **kwargs):
 
         self._copy = kwargs.pop("copy", True)
@@ -272,7 +272,6 @@ class CoordSet(HasTraits):
         # initialize the base class with the eventual remaining arguments
         super().__init__(**kwargs)
 
-    # ..........................................................................
     def implements(self, name=None):
         """
         Utility to check if the current object implement `CoordSet`.
@@ -289,7 +288,7 @@ class CoordSet(HasTraits):
     # ------------------------------------------------------------------------
     # Validation methods
     # ------------------------------------------------------------------------
-    # ..........................................................................
+
     @validate("_coords")
     def _coords_validate(self, proposal):
         coords = proposal["value"]
@@ -347,7 +346,6 @@ class CoordSet(HasTraits):
         else:
             return None
 
-    # ..........................................................................
     @default("_id")
     def _id_default(self):
         # a unique id
@@ -357,7 +355,6 @@ class CoordSet(HasTraits):
     # Readonly Properties
     # ------------------------------------------------------------------------
 
-    # ..........................................................................
     @property
     def available_names(self):
         """
@@ -371,7 +368,6 @@ class CoordSet(HasTraits):
                 _available_names.remove(item)
         return _available_names
 
-    # ..........................................................................
     @property
     def coords(self):
         """
@@ -379,7 +375,6 @@ class CoordSet(HasTraits):
         """
         return self._coords
 
-    # ..........................................................................
     @property
     def has_defined_name(self):
         """
@@ -387,7 +382,6 @@ class CoordSet(HasTraits):
         """
         return not (self.name == self.id)
 
-    # ..........................................................................
     @property
     def id(self):
         """
@@ -395,7 +389,6 @@ class CoordSet(HasTraits):
         """
         return self._id
 
-    # ..........................................................................
     @property
     def is_empty(self):
         """
@@ -406,7 +399,6 @@ class CoordSet(HasTraits):
         else:
             return False
 
-    # ..........................................................................
     @property
     def is_same_dim(self):
         """
@@ -414,12 +406,10 @@ class CoordSet(HasTraits):
         """
         return self._is_same_dim
 
-    # ..........................................................................
     @property
     def references(self):
         return self._references
 
-    # ..........................................................................
     @property
     def sizes(self):
         """
@@ -444,7 +434,6 @@ class CoordSet(HasTraits):
     # alias
     size = sizes
 
-    # ..........................................................................
     # @property
     # def coords(self):  #TODO: replace with itertiems, items etc ... to simulate a dict
     #     """
@@ -453,7 +442,6 @@ class CoordSet(HasTraits):
     #     """
     #     return self._coords
 
-    # ..........................................................................
     @property
     def names(self):
         """
@@ -483,7 +471,6 @@ class CoordSet(HasTraits):
         # return the first coordinates
         return self.default.data
 
-    # ..........................................................................
     @property
     def name(self):
         if self._name:
@@ -496,7 +483,6 @@ class CoordSet(HasTraits):
         if value is not None:
             self._name = value
 
-    # ..........................................................................
     @property
     def titles(self):
         """
@@ -514,7 +500,6 @@ class CoordSet(HasTraits):
                 raise ValueError("Something wrong with the titles!")
         return _titles
 
-    # ..........................................................................
     @property
     def labels(self):
         """
@@ -529,7 +514,6 @@ class CoordSet(HasTraits):
         """
         return any([item.is_labeled for item in self])
 
-    # ..........................................................................
     @property
     def units(self):
         """
@@ -540,7 +524,7 @@ class CoordSet(HasTraits):
     # ------------------------------------------------------------------------
     # public methods
     # ------------------------------------------------------------------------
-    # ..........................................................................
+
     def copy(self, keepname=False):
         """
         Make a disconnected copy of the current coords.
@@ -552,7 +536,6 @@ class CoordSet(HasTraits):
         """
         return self.__copy__()
 
-    # ..........................................................................
     def keys(self):
         """
         Alias for names.
@@ -569,14 +552,12 @@ class CoordSet(HasTraits):
             keys.extend(list(self.references.keys()))
         return keys
 
-    # ..........................................................................
     def select(self, val):
         """
         Select the default coord index.
         """
         self._default = min(max(0, int(val) - 1), len(self.names))
 
-    # ...........................................................................................................
     def set(self, *args, **kwargs):
         """
         Set one or more coordinates in the current CoordSet.
@@ -612,7 +593,6 @@ class CoordSet(HasTraits):
                 item._is_same_dim = True
             self[k] = item
 
-    # ..........................................................................
     def set_titles(self, *args, **kwargs):
         """
         Set one or more coord title at once.
@@ -645,7 +625,6 @@ class CoordSet(HasTraits):
         for k, item in kwargs.items():
             self[k].title = item
 
-    # ..........................................................................
     def set_units(self, *args, **kwargs):
         """
         Set one or more coord units at once.
@@ -682,7 +661,6 @@ class CoordSet(HasTraits):
         for k, item in kwargs.items():
             self[k].to(item, force=force, inplace=True)
 
-    # ..........................................................................
     def to_dict(self):
         """
         Return a dict of the coordinates from the coordset.
@@ -694,7 +672,6 @@ class CoordSet(HasTraits):
         """
         return dict(zip(self.names, self._coords))
 
-    # ..........................................................................
     def update(self, **kwargs):
         """
         Update a specific coordinates in the CoordSet.
@@ -715,7 +692,6 @@ class CoordSet(HasTraits):
     # private methods
     # ------------------------------------------------------------------------
 
-    # ..........................................................................
     def _append(self, coord):
         # utility function to append coordinate with full validation
         if not isinstance(coord, tuple):
@@ -729,7 +705,6 @@ class CoordSet(HasTraits):
             # no coordinates yet, start a new tuple of coordinate
             self._coords = (*coord,)
 
-    # ..........................................................................
     def _loc2index(self, loc):
         # Return the index of a location
         for coord in self.coords:
@@ -740,14 +715,12 @@ class CoordSet(HasTraits):
         # not found!
         raise IndexError
 
-    # ..........................................................................
     def _set_names(self, names):
         # utility function to change names of coordinates (in batch)
         # useful when a coordinate is a CoordSet itself
         for coord, name in zip(self._coords, names):
             coord.name = name
 
-    # ..........................................................................
     def _set_parent_dim(self, name):
         # utility function to set the paretn name for sub coordset
         for coord in self._coords:
@@ -757,12 +730,10 @@ class CoordSet(HasTraits):
     # special methods
     # ------------------------------------------------------------------------
 
-    # ..........................................................................
     # @staticmethod
     def __dir__(self):
         return ["coords", "references", "is_same_dim", "name"]
 
-    # ..........................................................................
     def __call__(self, *args, **kwargs):
         # allow the following syntax: coords(), coords(0,2) or
         coords = []
@@ -782,12 +753,10 @@ class CoordSet(HasTraits):
         else:
             return CoordSet(*coords)
 
-    # ..........................................................................
     def __hash__(self):
         # all instance of this class has same hash, so they can be compared
         return hash(tuple(self._coords))
 
-    # ..........................................................................
     def __len__(self):
         return len(self._coords)
 
@@ -801,7 +770,6 @@ class CoordSet(HasTraits):
             except (IndexError, KeyError):
                 raise AttributeError
 
-    # ..........................................................................
     def __getattr__(self, item):
         # when the attribute was not found
         if "_validate" in item or "_changed" in item:
@@ -812,7 +780,6 @@ class CoordSet(HasTraits):
         except (IndexError, KeyError):
             raise AttributeError
 
-    # ..........................................................................
     def __getitem__(self, index):
 
         if isinstance(index, str):
@@ -876,7 +843,6 @@ class CoordSet(HasTraits):
         else:
             return res
 
-    # ..........................................................................
     def __setattr__(self, key, value):
         keyb = key[1:] if key.startswith("_") else key
         if keyb in [
@@ -903,7 +869,6 @@ class CoordSet(HasTraits):
         except Exception:
             super().__setattr__(key, value)
 
-    # ..........................................................................
     def __setitem__(self, index, coord):
         try:
             coord = coord.copy(keepname=True)  # to avoid modifying the original
@@ -981,7 +946,6 @@ class CoordSet(HasTraits):
 
         self._coords[index] = coord
 
-    # ..........................................................................
     def __delitem__(self, index):
 
         if isinstance(index, str):
@@ -1015,12 +979,10 @@ class CoordSet(HasTraits):
 
             raise KeyError(f"Could not find `{index}` in coordinates names or titles")
 
-    # ..........................................................................
     # def __iter__(self):
     #    for item in self._coords:
     #        yield item
 
-    # ..........................................................................
     def __repr__(self):
         out = "CoordSet: [" + ", ".join(["{}"] * len(self._coords)) + "]"
         s = []
@@ -1032,11 +994,9 @@ class CoordSet(HasTraits):
         out = out.format(*s)
         return out
 
-    # ..........................................................................
     def __str__(self):
         return repr(self)
 
-    # ..........................................................................
     def _cstr(self, header="  coordinates: ... \n", print_size=True):
 
         txt = ""
@@ -1083,11 +1043,9 @@ class CoordSet(HasTraits):
         else:
             return txt.rstrip()
 
-    # ..........................................................................
     def _repr_html_(self):
         return convert_to_html(self)
 
-    # ..........................................................................
     def __deepcopy__(self, memo):
         coords = self.__class__(
             tuple(cpy.deepcopy(ax, memo=memo) for ax in self), keepnames=True
@@ -1097,7 +1055,6 @@ class CoordSet(HasTraits):
         coords._default = self._default
         return coords
 
-    # ..........................................................................
     def __copy__(self):
         coords = self.__class__(tuple(cpy.copy(ax) for ax in self), keepnames=True)
         # name must be changed
@@ -1107,8 +1064,6 @@ class CoordSet(HasTraits):
         coords._default = self._default
         return coords
 
-        # ..........................................................................
-
     def __eq__(self, other):
         if other is None:
             return False
@@ -1117,19 +1072,17 @@ class CoordSet(HasTraits):
         except Exception:
             return False
 
-    # ..........................................................................
     def __ne__(self, other):
         return not self.__eq__(other)
 
     # ------------------------------------------------------------------------
     # Events
     # ------------------------------------------------------------------------
-    # ..........................................................................
+
     def _coords_update(self, change):
         # when notified that a coord name have been updated
         self._updated = True
 
-    # ..........................................................................
     @observe(All)
     def _anytrait_changed(self, change):
         # ex: change {
