@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 Module containing 1D plotting function(s).
 """
@@ -17,26 +17,18 @@ __all__ = [
     "plot_scatter_pen",
 ]
 
-__dataset_methods__ = [
-    "plot_1D",
-    "plot_lines",
-    "plot_pen",
-    "plot_scatter",
-    "plot_bar",
-    "plot_scatter_pen",
-]
+__dataset_methods__ = __all__
 
 import numpy as np
 from matplotlib.ticker import MaxNLocator, ScalarFormatter
 
-from spectrochempy.utils import (
-    make_label,
-    is_sequence,
-    add_docstring,
-    plot_method,
-)  # , deprecated
 from spectrochempy.core.dataset.coord import Coord
-
+from spectrochempy.utils import (  # , deprecated
+    add_docstring,
+    is_sequence,
+    make_label,
+    plot_method,
+)
 
 _PLOT1D_DOC = """\
 ax : Axe, optional
