@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie,
-#  Caen, France.                                  =
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in
-#  the root directory                         =
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module defines functions related to NDDataset alignment.
 """
@@ -16,12 +14,11 @@ __dataset_methods__ = __all__
 # import scipy.interpolate
 import numpy as np
 
-from spectrochempy.utils import MASKED, UnitsCompatibilityError, get_n_decimals
-from spectrochempy.core import warning_, error_
+from spectrochempy.core import error_, warning_
 from spectrochempy.core.dataset.coord import Coord
+from spectrochempy.utils import MASKED, UnitsCompatibilityError, get_n_decimals
 
 
-# ..........................................................................
 def can_merge_or_align(coord1, coord2):
     """
     Check if two coordinates can be merged or aligned.
@@ -59,7 +56,6 @@ def can_merge_or_align(coord1, coord2):
     return can_merge, can_align
 
 
-# ............................................................................
 def align(dataset, *others, **kwargs):
     """
     Align individual |NDDataset| along given dimensions using various methods.
