@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 Plugin module to perform automatic subtraction of ref on a dataset.
 """
@@ -14,8 +14,7 @@ __dataset_methods__ = __all__
 import numpy as np
 from scipy.optimize import minimize_scalar
 
-
-from spectrochempy.core.dataset.coordrange import trim_ranges
+from spectrochempy.utils import trim_ranges
 
 
 def autosub(
@@ -161,9 +160,7 @@ def autosub(
     if swapped:
         new = new.swapdims(axis, -1)
 
-    new.history = (
-        str(new.modified) + ": " + "Automatic subtraction of:" + ref.name + "\n"
-    )
+    new.history = f"Automatic subtraction of {ref.name}"
 
     if return_coefs:
         return new, x
