@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# =============================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory
-# =============================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module implements the `BaselineCorrection` class for baseline corrections.
 """
@@ -11,19 +11,18 @@ __all__ = ["BaselineCorrection", "ab", "abc", "dc", "basc"]
 
 __dataset_methods__ = ["ab", "abc", "dc", "basc"]
 
+import matplotlib.pyplot as plt
 import numpy as np
 import scipy.interpolate
-from traitlets import Int, Instance, HasTraits, Float, Unicode, Tuple, List
 from matplotlib.widgets import SpanSelector
-import matplotlib.pyplot as plt
+from traitlets import Float, HasTraits, Instance, Int, List, Tuple, Unicode
 
-from spectrochempy.core.dataset.coordrange import trim_ranges
-from spectrochempy.core.plotters.multiplot import multiplot
-from spectrochempy.core.dataset.nddataset import NDDataset
-from spectrochempy.utils import TYPE_INTEGER, TYPE_FLOAT
 from spectrochempy.core import debug_, warning_
+from spectrochempy.core.dataset.nddataset import NDDataset
+from spectrochempy.core.plotters.multiplot import multiplot
+from spectrochempy.core.processors.smooth import smooth
 from spectrochempy.core.processors.utils import _units_agnostic_method
-from .smooth import smooth
+from spectrochempy.utils import TYPE_FLOAT, TYPE_INTEGER, trim_ranges
 
 
 class BaselineCorrection(HasTraits):
@@ -54,8 +53,7 @@ class BaselineCorrection(HasTraits):
         :include-source:
 
         from spectrochempy import *
-        nd = NDDataset.read_omnic(os.path.join('irdata',
-                                    'nh4y-activation.spg'))
+        nd = NDDataset.read_omnic('irdata/nh4y-activation.spg')
         ndp = nd[:, 1291.0:5999.0]
         bc = BaselineCorrection(ndp)
         ranges=[[5996., 5998.], [1290., 1300.],
@@ -79,7 +77,6 @@ class BaselineCorrection(HasTraits):
     figsize = Tuple((7, 5))
     sps = List()
 
-    # ..........................................................................
     def __init__(self, dataset, *args, **kwargs):
         self.dataset = dataset
         self.corrected = self.dataset.copy()
@@ -90,7 +87,6 @@ class BaselineCorrection(HasTraits):
                 "Here they are ignored."
             )
 
-    # ..........................................................................
     def _extendranges(self, *ranges, **kwargs):
         if not ranges:
             # look in the kwargs
@@ -115,7 +111,6 @@ class BaselineCorrection(HasTraits):
                 item = [item, item]
             self.ranges.append(item)
 
-    # ..........................................................................
     def _setup(self, **kwargs):
 
         self.method = kwargs.get("method", self.method)
@@ -127,12 +122,10 @@ class BaselineCorrection(HasTraits):
         self.zoompreview = kwargs.get("zoompreview", self.zoompreview)
         self.figsize = kwargs.get("figsize", self.figsize)
 
-    # ..........................................................................
     def __call__(self, *ranges, **kwargs):
 
         return self.compute(*ranges, **kwargs)
 
-    # ..........................................................................
     def compute(self, *ranges, **kwargs):
         """
         Base function for dataset baseline correction.
@@ -269,7 +262,7 @@ class BaselineCorrection(HasTraits):
         if is_descendant:
             new.sort(axis=-1, inplace=True, descend=True)
 
-        new.history = str(new.modified) + ": " + "Baseline correction." + " Method: "
+        new.history = "Baseline correction." + " Method: "
         if self.method == "Multivariate":
             new.history = "Multivariate (" + str(self.npc) + " PCs)."
         else:
@@ -286,7 +279,6 @@ class BaselineCorrection(HasTraits):
         self.corrected = new
         return new
 
-    # ..........................................................................
     def show_regions(self, ax):
         if self.sps:
             for sp in self.sps:
@@ -298,7 +290,6 @@ class BaselineCorrection(HasTraits):
             sp = ax.axvspan(x[0], x[1], facecolor="#2ca02c", alpha=0.5)
             self.sps.append(sp)
 
-    # ..........................................................................
     def run(self, *ranges, **kwargs):
         """
         Interactive version of the baseline correction.
@@ -418,7 +409,6 @@ class BaselineCorrection(HasTraits):
         return
 
 
-# ..............................................................................
 def basc(dataset, *ranges, **kwargs):
     """
     Compute a baseline correction using the BaselineCorrection processor.
@@ -606,7 +596,6 @@ def abc(dataset, dim=-1, **kwargs):
     return new
 
 
-# ..............................................................................
 def ab(dataset, dim=-1, **kwargs):
     """
     Alias of `abc`.
@@ -614,7 +603,6 @@ def ab(dataset, dim=-1, **kwargs):
     return abs(dataset, dim, **kwargs)
 
 
-# ..............................................................................
 @_units_agnostic_method
 def dc(dataset, **kwargs):
     """
