@@ -1,34 +1,31 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-# Copyright (©) 2015-2016 Christian Fernandez
-# Laboratoire Catalyse et Spectrochimie, Caen, France.
-#
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
 # CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
-# See full LICENSE agreement in the root directory
-# ======================================================================================================================
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 
 __all__ = ["fft", "ifft", "mc", "ps", "ht"]
 
 __dataset_methods__ = __all__
 
 import re
+
 import numpy as np
-from scipy.signal import hilbert
 from quaternion import as_float_array
+from scipy.signal import hilbert
 
 from spectrochempy.core import error_
-from spectrochempy.core.units import ur
 from spectrochempy.core.dataset.coord import LinearCoord
-from spectrochempy.utils import (
-    largest_power_of_2,
-    get_component,
-    typequaternion,
-    as_quaternion,
-)
 from spectrochempy.core.processors.utils import _units_agnostic_method
 from spectrochempy.core.processors.zero_filling import zf_size
-
+from spectrochempy.core.units import ur
+from spectrochempy.utils import (
+    as_quaternion,
+    get_component,
+    largest_power_of_2,
+    typequaternion,
+)
 
 # ======================================================================================================================
 # Private methods
@@ -541,7 +538,7 @@ def fft(dataset, size=None, sizeff=None, inv=False, ppm=True, **kwargs):
             ppm = kwargs.get("ppm", True)
             if ppm:
                 newcoord.ito("ppm")
-                newcoord.title = fr"$\delta\ {nucleus}$"
+                newcoord.title = rf"$\delta\ {nucleus}$"
 
         new.coordset[dim] = newcoord
 
@@ -597,7 +594,7 @@ def mc(dataset):
 
     Calculates sqrt(real^2 + imag^2)
     """
-    return np.sqrt(dataset.real ** 2 + dataset.imag ** 2)
+    return np.sqrt(dataset.real**2 + dataset.imag**2)
 
 
 @_units_agnostic_method
@@ -607,7 +604,7 @@ def ps(dataset):
 
     Calculated real^2+imag^2
     """
-    return dataset.real ** 2 + dataset.imag ** 2
+    return dataset.real**2 + dataset.imag**2
 
 
 @_units_agnostic_method
