@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
-
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 A collection of NMR spectral processing functions which operate on the last
 dimension (1) of 2D arrays.
@@ -14,10 +13,11 @@ __all__ = ["pk", "pk_exp"]
 __dataset_methods__ = __all__
 
 import functools
+
 import numpy as np
 
-from spectrochempy.core.units import ur, Quantity
 from spectrochempy.core import error_
+from spectrochempy.core.units import Quantity, ur
 
 pi = np.pi
 
