@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 In this module, methods are provided to download external datasets
 from public database.
@@ -12,26 +12,26 @@ __all__ = ["download_iris", "download_nist_ir"]
 __dataset_methods__ = __all__
 
 from io import StringIO
-import numpy as np
-import requests
-from datetime import datetime, timezone
 from pathlib import Path
 
-from spectrochempy.core.dataset.nddataset import NDDataset
-from spectrochempy.core.dataset.coord import Coord
-from spectrochempy.core.readers.read_jcamp import read_jcamp
+import numpy as np
+import requests
+
 from spectrochempy.core import error_, info_
-from spectrochempy.optional import import_optional_dependency
+from spectrochempy.core.dataset.coord import Coord
+from spectrochempy.core.dataset.nddataset import NDDataset
+from spectrochempy.core.readers.read_jcamp import read_jcamp
 from spectrochempy.utils import is_iterable
+from spectrochempy.utils.optional import import_optional_dependency
 
 
-# ..............................................................................
 def download_iris():
     """
-    Upload the classical `IRIS` dataset.
+    Upload the classical "iris" dataset.
 
-    The `IRIS` dataset is a classical example for machine learning.It is downloaded from
-    the [UCI distant repository](https://archive.ics.uci.edu/ml/machine-learning-databases/iris/iris.data)
+    The "IRIS" dataset is a classical example for machine learning.It is downloaded from
+    the
+    [UCI distant repository](https://archive.ics.uci.edu/ml/machine-learning-databases/iris/iris.data)
 
     Returns
     -------
@@ -201,9 +201,7 @@ def download_nist_ir(CAS, index="all"):
             ds = read_jcamp("temp.jdx")
 
             # replace the default entry ":imported from jdx file":
-            ds.history[0] = ds.history[0][: len(str(datetime.now(timezone.utc)))] + (
-                f" : downloaded from NIST: {url}\n"
-            )
+            ds.history[0] = f"Downloaded from NIST: {url}"
             out.append(ds)
             (Path(".") / "temp.jdx").unlink()
 
