@@ -1,31 +1,36 @@
-#  -*- coding: utf-8 -*-
-#
-#  =====================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.                                  =
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory                         =
-#  =====================================================================================================================
-#
+# -*- coding: utf-8 -*-
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module define a generic class to import directories, files and contents.
 """
 __all__ = ["read", "read_dir", "read_remote"]
 __dataset_methods__ = __all__
 
+from io import BytesIO
+from warnings import warn
+from zipfile import ZipFile
+
 import requests
 import yaml
+from traitlets import Dict, HasTraits, List, Type, Unicode
 
-from warnings import warn
-from datetime import datetime, timezone
-from traitlets import HasTraits, List, Dict, Type, Unicode
-
-from spectrochempy.utils import pathclean, check_filename_to_open
-from spectrochempy.utils import get_directory_name, get_filenames
+from spectrochempy.core import info_, warning_
+from spectrochempy.utils import (
+    check_filename_to_open,
+    get_directory_name,
+    get_filenames,
+    pathclean,
+)
 from spectrochempy.utils.exceptions import DimensionsCompatibilityError, ProtocolError
-from spectrochempy.core import warning_
 
 FILETYPES = [
     ("scp", "SpectroChemPy files (*.scp)"),
     ("omnic", "Nicolet OMNIC files and series (*.spa *.spg *.srs)"),
+    ("soc", "Surface Optics Corp. (*.ddr *.hdr *.sdr)"),
     ("labspec", "LABSPEC exported files (*.txt)"),
     ("opus", "Bruker OPUS files (*.[0-9]*)"),
     (
@@ -46,6 +51,9 @@ FILETYPES = [
 ALIAS = [
     ("spg", "omnic"),
     ("spa", "omnic"),
+    ("ddr", "soc"),
+    ("hdr", "soc"),
+    ("sdr", "soc"),
     ("spc", "galactic"),
     ("srs", "omnic"),
     ("mat", "matlab"),
@@ -83,7 +91,6 @@ class Importer(HasTraits):
 
         self.alias = dict(ALIAS)
 
-    # ..........................................................................
     def __call__(self, *args, **kwargs):
 
         self.datasets = []
@@ -162,7 +169,6 @@ class Importer(HasTraits):
                 nds, key=str
             )  # return a sorted list (sorted according to their string representation)
 
-    # ..........................................................................
     def _setup_objtype(self, *args, **kwargs):
         # check if the first argument is an instance of NDDataset or Project
 
@@ -184,7 +190,6 @@ class Importer(HasTraits):
 
         return args, kwargs
 
-    # ..........................................................................
     def _switch_protocol(self, key, files, **kwargs):
 
         protocol = kwargs.get("protocol", None)
@@ -262,9 +267,7 @@ class Importer(HasTraits):
                 dataset = self.objtype.concatenate(datasets, axis=0)
                 if dataset.coordset is not None and kwargs.pop("sortbydate", True):
                     dataset.sort(dim="y", inplace=True)
-                    dataset.history = (
-                        str(datetime.now(timezone.utc)) + ":sorted by date"
-                    )
+                    dataset.history = "Sorted by date"
                 datasets = [dataset]
 
             except DimensionsCompatibilityError as e:
@@ -273,7 +276,6 @@ class Importer(HasTraits):
         return datasets
 
 
-# ..............................................................................
 def _importer_method(func):
     # Decorator to define a given read function as belonging to Importer
     setattr(Importer, func.__name__, staticmethod(func))
@@ -552,6 +554,14 @@ def read_remote(file_or_dir, **kwargs):
     return importer(file_or_dir, **kwargs)
 
 
+def _write_downloaded_file(content, dst):
+    if not dst.parent.exists():
+        # create the eventually missing subdirectory
+        dst.parent.mkdir(parents=True, exist_ok=True)
+    dst.write_bytes(content)
+    info_(f"{dst.name} has been downloaded and written in {dst.parent}")
+
+
 def _get_url_content_and_save(url, dst, replace):
 
     if not replace and dst.exists():
@@ -561,16 +571,33 @@ def _get_url_content_and_save(url, dst, replace):
         r = requests.get(url, allow_redirects=True)
 
         # write downloaded file
-        if not dst.parent.exists():
-            # create the eventually missing subdirectory
-            dst.parent.mkdir(parents=True, exist_ok=True)
-        dst.write_bytes(r.content)
-        print(f"{dst.name} has been downloaded and written in {dst.parent}")
+        _write_downloaded_file(r.content, dst)
 
     except OSError:
         raise FileNotFoundError(f"Not found locally or on github (url:{url}")
 
 
+def _download_full_testdata_directory():
+    from spectrochempy.core import preferences as prefs
+
+    datadir = prefs.datadir
+
+    url = "https://github.com/spectrochempy/spectrochempy_data/archive/refs/heads/master.zip"
+
+    resp = requests.get(url)
+    zipfile = ZipFile(BytesIO(resp.content))
+    files = [zipfile.open(file_name) for file_name in zipfile.namelist()]
+
+    for file in files:
+        name = file.name
+        if name.endswith("/") or "testdata/" not in name:  # dir
+            continue
+        uncompressed = zipfile.read(name)
+        p = list(pathclean(name).parts)[2:]
+        dst = datadir.joinpath("/".join(p))
+        _write_downloaded_file(uncompressed, dst)
+
+
 def _download_from_url(url, dst, replace=False):
     # ##
     # ##    Do not forget to change the fork in the following url
@@ -643,7 +670,11 @@ def _read_remote(*args, **kwargs):
 
     replace = kwargs.pop("replace_existing", False)
     dst = datadir / relative_path
-    _download_from_url(relative_path, dst, replace)
+    if dst.name != "testdata":
+        _download_from_url(relative_path, dst, replace)
+    else:
+        # we are going to download the whole testdata directory -> use a faster method
+        _download_full_testdata_directory()
 
     if not kwargs.pop("download_only", False):
         read_method = kwargs.pop("read_method", read)
@@ -672,14 +703,12 @@ def _read_dir(*args, **kwargs):
     return datasets
 
 
-# ..............................................................................
 @_importer_method
 def _read_scp(*args, **kwargs):
     dataset, filename = args
     return dataset.load(filename, **kwargs)
 
 
-# ..............................................................................
 @_importer_method
 def _read_(*args, **kwargs):
     dataset, filename = args
