@@ -1,33 +1,31 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module provides methods for reading data in a directory after a carroucell experiment.
 """
 __all__ = ["read_carroucell"]
 __dataset_methods__ = __all__
 
-import os
-import warnings
 import datetime
+import os
 import re
+import warnings
 
-import scipy.interpolate
 import numpy as np
+import scipy.interpolate
 import xlrd
 
-from spectrochempy.core.dataset.nddataset import NDDataset
-from spectrochempy.core.dataset.coord import Coord
-from spectrochempy.utils import get_directory_name, get_filenames
 from spectrochempy.core import info_, print_
-
-from spectrochempy.core.readers.importer import _importer_method, Importer
+from spectrochempy.core.dataset.coord import Coord
+from spectrochempy.core.dataset.nddataset import NDDataset
+from spectrochempy.core.readers.importer import Importer, _importer_method
+from spectrochempy.utils import get_directory_name, get_filenames
 
 
-# ..............................................................................
 def read_carroucell(directory=None, **kwargs):
     """
     Open .spa files in a directory after a carroucell experiment.
