@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
-
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 __all__ = ["read_csv"]
 __dataset_methods__ = __all__
 
@@ -12,15 +11,15 @@ __dataset_methods__ = __all__
 # standard and other imports
 # ------------------------------------------------------------------
 
-import warnings
-import locale
 import io
-from datetime import datetime, timezone
+import locale
+import warnings
+from datetime import datetime
 
 import numpy as np
 
-from spectrochempy.core.dataset.coord import Coord
 from spectrochempy.core import preferences as prefs
+from spectrochempy.core.dataset.coord import Coord
 from spectrochempy.core.readers.importer import Importer, _importer_method
 
 try:
@@ -207,9 +206,7 @@ def _read_csv(*args, **kwargs):
     dataset.title = kwargs.get("title", None)
     dataset.units = kwargs.get("units", None)
     dataset.description = kwargs.get("description", '"name" ' + "read from .csv file")
-    dataset.history = str(datetime.now(timezone.utc)) + ":read from .csv file \n"
-    dataset._date = datetime.now(timezone.utc)
-    dataset._modified = dataset.date
+    dataset.history = "Read from .csv file"
 
     # here we can check some particular format
     origin = kwargs.get("origin", "")
@@ -225,10 +222,13 @@ def _read_csv(*args, **kwargs):
             "Please, remove or set the keyword 'origin'\n "
             "(Up to now implemented csv files are: `omnic`, `tga`)"
         )
+
+    # reset modification date to cretion date
+    dataset._modified = dataset._created
+
     return dataset
 
 
-# .............................................................................
 def _add_omnic_info(dataset, **kwargs):
     # get the time and name
     name = desc = dataset.name
@@ -238,15 +238,9 @@ def _add_omnic_info(dataset, **kwargs):
     dataset.title = "absorbance"
     dataset.name = name
     dataset.description = "Dataset from .csv file: {}\n".format(desc)
-    dataset.history = (
-        str(datetime.now(timezone.utc)) + ":read from omnic exported csv file \n"
-    )
+    dataset.history = "Read from omnic exported csv file."
     dataset.origin = "omnic"
 
-    # Set the NDDataset date
-    dataset._date = datetime.now(timezone.utc)
-    dataset._modified = dataset.date
-
     # x axis
     dataset.x.units = "cm^-1"
 
@@ -277,6 +271,9 @@ def _add_omnic_info(dataset, **kwargs):
         dataset.y.labels = np.array([[acqdate], [name]])
         dataset.y.units = "s"
 
+    # reset modification date to cretion date
+    dataset._modified = dataset._created
+
     return dataset
 
 
