@@ -1,13 +1,9 @@
-#  -*- coding: utf-8 -*-
-#
-#  =====================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.                                  =
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory                         =
-#  =====================================================================================================================
-#
-# author: Guillaume Clet (LCS)
-#
-
+# -*- coding: utf-8 -*-
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module extend NDDataset with the import method for Labspec *.txt generated data files.
 """
@@ -16,11 +12,12 @@ __all__ = ["read_labspec"]
 __dataset_methods__ = __all__
 
 import datetime
+
 import numpy as np
 
+from spectrochempy.core.common.meta import Meta
 from spectrochempy.core.dataset.coord import Coord, LinearCoord
-from spectrochempy.core.readers.importer import _importer_method, Importer
-from spectrochempy.core.dataset.meta import Meta
+from spectrochempy.core.readers.importer import Importer, _importer_method
 
 
 # ======================================================================================================================
@@ -108,11 +105,11 @@ def read_labspec(*paths, **kwargs):
 read_txt = read_labspec
 
 
-# ======================================================================================================================
+# ======================================================================================
 # Private functions
-# ======================================================================================================================
+# ======================================================================================
+
 
-# ..............................................................................
 @_importer_method
 def _read_txt(*args, **kwargs):
     # read Labspec *txt files or series
@@ -196,12 +193,11 @@ def _read_txt(*args, **kwargs):
     # date_acq is Acquisition date at start (first moment of acquisition)
     dataset.description = "Spectrum acquisition : " + str(date_acq)
 
-    # Set the NDDataset date
-    dataset._date = datetime.datetime.now(datetime.timezone.utc)
-    dataset._modified = dataset.date
-
     # Set origin, description and history
-    dataset.history = f"{dataset.date}:imported from LabSpec6 text file {filename}"
+    dataset.history = f"Imported from LabSpec6 text file {filename}"
+
+    # reset modification date to cretion date
+    dataset._modified = dataset._created
 
     return dataset
 
