@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
-
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 Plugin module to extend NDDataset with the import methods method.
 """
@@ -13,13 +12,13 @@ __all__ = ["read_matlab", "read_mat"]
 __dataset_methods__ = __all__
 
 import io
+from datetime import datetime
 from warnings import warn
-from datetime import datetime, timezone
 
 import numpy as np
 import scipy.io as sio
 
-from spectrochempy.core.dataset.nddataset import NDDataset, Coord
+from spectrochempy.core.dataset.nddataset import Coord, NDDataset
 from spectrochempy.core.readers.importer import Importer, _importer_method
 
 
@@ -107,7 +106,6 @@ def read_matlab(*paths, **kwargs):
     return importer(*paths, **kwargs)
 
 
-# ..............................................................................
 read_mat = read_matlab
 
 
@@ -154,9 +152,7 @@ def _read_mat(*args, **kwargs):
             # this is an array of numbers
             dataset.data = data
             dataset.name = name
-            dataset.history = (
-                str(datetime.now(timezone.utc)) + ":imported from .mat file \n"
-            )
+            dataset.history = "Imported from .mat file"
             # TODO: reshape from fortran/Matlab order to C opder
             # for 3D or higher datasets ?
             datasets.append(dataset)
@@ -279,11 +275,9 @@ def _read_dso(dataset, name, data):
             dataset.description += i
 
         for i in data["history"][0][0][0][0]:
-            dataset.history.append(i)
+            dataset.history = i
 
-        dataset.history = (
-            str(datetime.now(timezone.utc)) + ": Imported by spectrochempy "
-        )
+        dataset.history = "Imported by spectrochempy."
     return dataset
 
 
