@@ -1,10 +1,9 @@
-#  -*- coding: utf-8 -*-
-#
-#  =====================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory
-#  =====================================================================================================================
-#
+# -*- coding: utf-8 -*-
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module extend NDDataset with the import method for OMNIC generated data
 files.
@@ -12,20 +11,17 @@ files.
 __all__ = ["read_omnic", "read_spg", "read_spa", "read_srs"]
 __dataset_methods__ = __all__
 
-from datetime import datetime, timezone, timedelta
 import io
 import re
 import struct
+from datetime import datetime, timedelta, timezone
 
 import numpy as np
 
 from spectrochempy.core import info_
 from spectrochempy.core.dataset.coord import Coord, LinearCoord
 from spectrochempy.core.dataset.nddataset import NDDataset
-from spectrochempy.core.readers.importer import (
-    _importer_method,
-    Importer,
-)
+from spectrochempy.core.readers.importer import Importer, _importer_method
 from spectrochempy.core.units import ur
 
 
@@ -217,7 +213,6 @@ def read_omnic(*paths, **kwargs):
     return importer(*paths, **kwargs)
 
 
-# ..............................................................................
 def read_spg(*paths, **kwargs):
     """
     Open a Thermo Nicolet file or a list of files with extension ``.spg``.
@@ -312,7 +307,6 @@ def read_spg(*paths, **kwargs):
     return importer(*paths, **kwargs)
 
 
-# ..............................................................................
 def read_spa(*paths, **kwargs):
     """
     Open a Thermo Nicolet file or a list of files with extension ``.spa``.
@@ -413,7 +407,6 @@ def read_spa(*paths, **kwargs):
     return importer(*paths, **kwargs)
 
 
-# ..............................................................................
 def read_srs(*paths, **kwargs):
     """
     Open a Thermo Nicolet file or a list of files with extension ``.srs``.
@@ -513,7 +506,7 @@ def read_srs(*paths, **kwargs):
 # Private functions
 # ======================================================================================
 
-# ......................................................................................
+
 @_importer_method
 def _read_spg(*args, **kwargs):
     # read spg file
@@ -733,19 +726,16 @@ def _read_spg(*args, **kwargs):
 
     dataset._date = datetime.now(timezone.utc)
 
-    dataset.history = str(dataset.date) + ":imported from spg file {} ; ".format(
-        filename
-    )
+    dataset.history = f"Imported from spg file {filename}."
     if sortbydate:
         dataset.sort(dim="y", inplace=True)
-        dataset.history = str(dataset.date) + ":sorted by date"
+        dataset.history = "Sorted by date"
 
     # debug_("end of reading")
 
     return dataset
 
 
-# ..............................................................................
 @_importer_method
 def _read_spa(*args, **kwargs):
     dataset, filename = args
@@ -930,7 +920,7 @@ def _read_spa(*args, **kwargs):
         for comment in spa_comments:
             dataset.description += comment + "\n---------------------\n"
 
-    dataset.history = str(datetime.now(timezone.utc)) + ":imported from spa file(s)"
+    dataset.history = "Imported from spa file(s)"
 
     if "spa_history" in locals():
         if len("spa_history".strip(" ")) > 0:
@@ -958,7 +948,6 @@ def _read_spa(*args, **kwargs):
     return dataset
 
 
-# ..............................................................................
 @_importer_method
 def _read_srs(*args, **kwargs):
     dataset, filename = args
@@ -1156,7 +1145,6 @@ def _read_srs(*args, **kwargs):
     return dataset
 
 
-# ..............................................................................
 def _fromfile(fid, dtype, count):
     # to replace np.fromfile in case of io.BytesIO object instead of byte
     # object
@@ -1182,7 +1170,6 @@ def _fromfile(fid, dtype, count):
     return np.array(out)
 
 
-# ..............................................................................
 def _readbtext(fid, pos, size):
     # Read some text in binary file of given size. If size is None, the etxt is read
     # until b\0\ is encountered.
@@ -1212,13 +1199,11 @@ def _readbtext(fid, pos, size):
     return text
 
 
-# ..............................................................................
 def _nextline(pos):
     # reset current position to the beginning of next line (16 bytes length)
     return 16 * (1 + pos // 16)
 
 
-# ..............................................................................
 def _read_header(fid, pos):
     """
     read spectrum/ifg/series header
@@ -1404,7 +1389,6 @@ def _read_header(fid, pos):
     return out
 
 
-# ..............................................................................
 def _getintensities(fid, pos):
     # get intensities from the 03 (spectrum)
     # or 66 (sample ifg) or 67 (bg ifg) key,
