@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module extend NDDataset with the import method for OPUS generated data files.
 """
@@ -11,13 +11,14 @@ __all__ = ["read_opus"]
 __dataset_methods__ = __all__
 
 import io
-import numpy as np
-from datetime import datetime, timezone, timedelta
+from datetime import datetime, timedelta, timezone
 
+import numpy as np
 from brukeropusreader.opus_parser import parse_data, parse_meta
-from spectrochempy.core.dataset.coord import LinearCoord, Coord
-from spectrochempy.core.readers.importer import Importer, _importer_method
+
 from spectrochempy.core import debug_
+from spectrochempy.core.dataset.coord import Coord, LinearCoord
+from spectrochempy.core.readers.importer import Importer, _importer_method
 
 
 # ======================================================================================================================
@@ -164,7 +165,7 @@ def read_opus(*paths, **kwargs):
 # Private Functions
 # ======================================================================================================================
 
-# ..............................................................................
+
 @_importer_method
 def _read_opus(*args, **kwargs):
     debug_("Bruker OPUS import")
@@ -201,9 +202,14 @@ def _read_opus(*args, **kwargs):
     acqdate = opus_data["AB Data Parameter"]["DAT"]
     acqtime = opus_data["AB Data Parameter"]["TIM"]
     gmt_offset_hour = float(acqtime.split("GMT")[1].split(")")[0])
-    date_time = datetime.strptime(
-        acqdate + "_" + acqtime.split()[0], "%d/%m/%Y_%H:%M:%S.%f"
-    )
+    if len(acqdate.split("/")[0]) == 2:
+        date_time = datetime.strptime(
+            acqdate + "_" + acqtime.split()[0], "%d/%m/%Y_%H:%M:%S.%f"
+        )
+    elif len(acqdate.split("/")[0]) == 4:
+        date_time = datetime.strptime(
+            acqdate + "_" + acqtime.split()[0], "%Y/%m/%d_%H:%M:%S"
+        )
     utc_dt = date_time - timedelta(hours=gmt_offset_hour)
     utc_dt = utc_dt.replace(tzinfo=timezone.utc)
     timestamp = utc_dt.timestamp()
@@ -225,13 +231,13 @@ def _read_opus(*args, **kwargs):
     dataset.origin = "opus"
     dataset.description = "Dataset from opus files. \n"
     dataset.history = str(datetime.now(timezone.utc)) + ": import from opus files \n"
-    dataset._date = datetime.now(timezone.utc)
-    dataset._modified = dataset.date
+
+    # reset modification date to cretion date
+    dataset._modified = dataset._created
 
     return dataset
 
 
-# ..............................................................................
 def _read_data(fid):
     data = fid.read()
     meta_data = parse_meta(data)
