@@ -1,28 +1,25 @@
-#  -*- coding: utf-8 -*-
-#
-#  =====================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie,
-#  Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in
-#  the root directory
-#  =====================================================================================================================
-#
+# -*- coding: utf-8 -*-
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module extend NDDataset with the import method for Thermo galactic (spc) data files.
 """
 __all__ = ["read_spc"]
 __dataset_methods__ = __all__
 
-from datetime import datetime, timezone
 import io
 import struct
+from datetime import datetime
+from warnings import warn
 
 import numpy as np
-from warnings import warn
 
 from spectrochempy.core.dataset.coord import Coord, LinearCoord
 from spectrochempy.core.dataset.nddataset import NDDataset
-from spectrochempy.core.readers.importer import _importer_method, Importer
+from spectrochempy.core.readers.importer import Importer, _importer_method
 from spectrochempy.core.units import Quantity
 
 # ======================================================================================================================
@@ -116,11 +113,11 @@ def read_spc(*paths, **kwargs):
     return importer(*paths, **kwargs)
 
 
-# ======================================================================================================================
+# ======================================================================================
 # Private functions
-# ======================================================================================================================
+# ======================================================================================
+
 
-# ..............................................................................
 @_importer_method
 def _read_spc(*args, **kwargs):
     dataset, filename = args
@@ -577,9 +574,7 @@ def _read_spc(*args, **kwargs):
             if Logsizd:
                 dataset.description += f"a Log disk block of size {Logsizd} bytes "
 
-    dataset.history = str(
-        datetime.now(timezone.utc)
-    ) + ":imported from spc file {} ; ".format(filename)
+    dataset.history = f"Imported from spc file {filename}."
 
     if y_unit == "Interferogram":
         # interferogram
