@@ -1,10 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
-
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 Bruker file (single dimension FID or multidimensional SER) importers.
 """
@@ -18,12 +17,12 @@ import numpy as np
 from quaternion import as_quat_array
 
 from spectrochempy.core import debug_
-from spectrochempy.core.dataset.meta import Meta
+from spectrochempy.core.common.meta import Meta
 from spectrochempy.core.dataset.coord import LinearCoord
-from spectrochempy.core.units import ur
-from spectrochempy.utils.exceptions import deprecated
 from spectrochempy.core.readers.importer import Importer, _importer_method
-from spectrochempy.utils.nmrglue import read_fid, read_pdata
+from spectrochempy.core.units import ur
+from spectrochempy.extern.nmrglue import read_fid, read_pdata
+from spectrochempy.utils.exceptions import deprecated
 
 # ======================================================================================================================
 # Constants
@@ -783,7 +782,6 @@ def read_bruker_nmr(*args, **kwargs):
     return read_topspin(*args, **kwargs)
 
 
-# ..............................................................................
 def _get_files(path, typ="acqu"):
     files = []
     for i in ["", 2, 3]:
@@ -897,7 +895,6 @@ def _read_topspin(*args, **kwargs):
         else:
             data = datalist
 
-    # ........................................................................................................
     # we now make some rearrangement of the dic to have something more user friendly
     # we assume that all experiments have similar (important) parameters so that the experiments are compatibles
 
