@@ -1,24 +1,16 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
-
-import re
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 import ast
+import re
 
-from traitlets import (
-    HasTraits,
-    Unicode,
-    validate,
-    TraitError,
-    Instance,
-    Float,
-)
+from traitlets import Float, HasTraits, Instance, TraitError, Unicode, validate
 
-from spectrochempy.core.project.baseproject import AbstractProject
 from spectrochempy.core import error_
+from spectrochempy.core.project.baseproject import AbstractProject
 
 __all__ = ["Script", "run_script", "run_all_scripts"]
 
@@ -148,7 +140,7 @@ class Script(HasTraits):
     # ------------------------------------------------------------------------
     # Public methods
     # ------------------------------------------------------------------------
-    # ..........................................................................
+
     def implements(self, name=None):
         """
         Utility to check if the current object implement `Project`.
