@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 The core interface to the Pint library.
 """
@@ -14,26 +14,41 @@ __all__ = [
     "ur",
     "set_nmr_context",
     "DimensionalityError",
-    "remove_args_units",
 ]
 
-from warnings import warn
 from functools import wraps
+from warnings import warn
 
 from pint import (
-    set_application_registry,
-    UnitRegistry,
-    DimensionalityError,
-    formatting,
     Context,
+    DimensionalityError,
+    UnitRegistry,
+    __version__,
+    formatting,
+    set_application_registry,
 )
 
+# check pint version
+pint_version = int(__version__.split(".")[1])
+if pint_version < 18:
+    raise ImportError(
+        "Current pint version is {__version__} but must be 0.18 or higher. Please consider upgrading it "
+        "(e.g. `> pip install pint --upgrade` or `> conda update pint`)\n"
+    )
+if pint_version < 20:
+    print(
+        f"Warning: current pint version is {__version__}. It might not be supported by SpectroChemPy in the future.\n"
+        f"Please consider upgrading it to 0.20 or higher (e.g. `> pip install pint --upgrade` or `> conda update pint`)\n"
+    )
 
-from pint.unit import UnitsContainer, Unit, UnitDefinition
-from pint.quantity import Quantity
+    from pint.converters import ScaleConverter
+    from pint.quantity import Quantity
+    from pint.unit import Unit, UnitDefinition, UnitsContainer
+else:
+    from pint import Quantity, Unit
+    from pint.facets.plain import ScaleConverter, UnitDefinition
+    from pint.util import UnitsContainer
 
-# from pint.formatting import siunitx_format_unit
-from pint.converters import ScaleConverter
 
 # ======================================================================================================================
 # Modify the pint behaviour
@@ -277,8 +292,26 @@ if globals().get("U_", None) is None:
 
     U_.define("ppm = 1. = ppm")
 
-    U_.define(UnitDefinition("percent", "pct", (), ScaleConverter(1 / 100.0)))
-    U_.define(UnitDefinition("weight_percent", "wt_pct", (), ScaleConverter(1 / 100.0)))
+    if pint_version < 20:
+        U_.define(UnitDefinition("percent", "pct", (), ScaleConverter(1 / 100.0)))
+        U_.define(
+            UnitDefinition("weight_percent", "wt_pct", (), ScaleConverter(1 / 100.0))
+        )
+    else:
+        U_.define(
+            UnitDefinition(
+                "percent", "pct", (), ScaleConverter(1 / 100.0), UnitsContainer()
+            )
+        )
+        U_.define(
+            UnitDefinition(
+                "weight_percent",
+                "wt_pct",
+                (),
+                ScaleConverter(1 / 100.0),
+                UnitsContainer(),
+            )
+        )
 
     U_.default_format = "~P"
     Q_ = U_.Quantity
