@@ -1,19 +1,18 @@
-#  -*- coding: utf-8 -*-
-#
-#  =====================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.                                  =
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory                         =
-#  =====================================================================================================================
-#
+# -*- coding: utf-8 -*-
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 This module define a generic class to import files and contents.
 """
 __all__ = ["write"]
 __dataset_methods__ = __all__
 
-from traitlets import HasTraits, Any
+from traitlets import Any, HasTraits
 
-from spectrochempy.utils import pathclean, check_filename_to_save, patterns
+from spectrochempy.utils import check_filename_to_save, pathclean, patterns
 
 
 # ------------------------------------------------------------------
@@ -40,7 +39,6 @@ class Exporter(HasTraits):
             for s in patterns(filter, allcase=False):
                 self.protocols[s[1:]] = protocol
 
-    # ..........................................................................
     def __call__(self, *args, **kwargs):
 
         args = self._setup_object(*args)
@@ -64,7 +62,6 @@ class Exporter(HasTraits):
         except Exception as e:
             raise e
 
-    # ..........................................................................
     def _setup_object(self, *args):
 
         # check if the first argument is an instance of NDDataset or Project
@@ -86,7 +83,6 @@ class Exporter(HasTraits):
         return args
 
 
-# ..............................................................................
 def exportermethod(func):
     # Decorator
     setattr(Exporter, func.__name__, staticmethod(func))
@@ -136,15 +132,15 @@ def write(dataset, filename=None, **kwargs):
     write a dataset (providing a windows type filename relative to the default ``Datadir``)
 
     >>> nd = scp.read_opus('irdata/OPUS')
-    >>> f = nd.write('opus.scp')
-    >>> f.name
-    'opus.scp'
+    >>> f = nd.write('opus.scp') # doctest: +SKIP
+    >>> f.name                   # doctest: +SKIP
+    'opus.scp'                   # doctest: +SKIP
+
     """
     exporter = Exporter()
     return exporter(dataset, filename, **kwargs)
 
 
-# ..............................................................................
 @exportermethod
 def _write_scp(*args, **kwargs):
     dataset, filename = args
