@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie,
-#  Caen, France.                                  =
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in
-#  the root directory                         =
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 Database isotopes for NMR.
 
@@ -18,11 +16,12 @@ __all__ = ["Isotopes"]
 import pathlib
 import re
 from fractions import Fraction
+
 import numpy as np
 
-from spectrochempy.core.units import ur
 from spectrochempy.core import preferences as prefs
-from spectrochempy.core.dataset.meta import Meta
+from spectrochempy.core.common.meta import Meta
+from spectrochempy.core.units import ur
 
 
 # ======================================================================================================================
