@@ -1,27 +1,26 @@
 # -*- coding: utf-8 -*-
-
-#  =====================================================================================================================
-#  Copyright (©) 2015-$today.year LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory
-#  =====================================================================================================================
-#
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 import matplotlib as mpl
 from matplotlib import pyplot as plt
 from matplotlib.lines import Line2D
 from traitlets import (
-    Bool,
-    Unicode,
-    Tuple,
-    List,
-    Integer,
-    Float,
-    Enum,
-    observe,
     All,
-    default,
-    TraitError,
-    Union,
+    Bool,
+    Enum,
+    Float,
+    Integer,
+    List,
     Set,
+    TraitError,
+    Tuple,
+    Unicode,
+    Union,
+    default,
+    observe,
 )
 
 from spectrochempy.utils import MetaConfigurable, get_pkg_path, pathclean
@@ -880,7 +879,6 @@ class PlotPreferences(MetaConfigurable):
         config=True
     )
 
-    # ..........................................................................
     def __init__(self, **kwargs):
         super().__init__(jsonfile="PlotPreferences", **kwargs)
         for key in plt.rcParams:
@@ -899,7 +897,7 @@ class PlotPreferences(MetaConfigurable):
 
     @property
     def members(self):
-        return self.members
+        return self._members
 
     @property
     def groups(self):
