@@ -1,18 +1,21 @@
 # -*- coding: utf-8 -*-
-
-# ============================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory
-# ============================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 
 import functools
 import warnings
 from contextlib import contextmanager
 
+import pytz
+
 __all__ = [
     "SpectroChemPyWarning",
-    "SpectroChemPyException",
+    "SpectroChemPyError",
     "UnitsCompatibilityError",
+    "UnknownTimeZoneError",
     "DimensionsCompatibilityError",
     "CoordinateMismatchError",
     "ProtocolError",
@@ -33,14 +36,14 @@ class SpectroChemPyWarning(Warning):
 
 
 # ------------------------------------------------------------------------------
-class SpectroChemPyException(Exception):
+class SpectroChemPyError(Exception):
     """
     The base exception class for SpectroChemPy.
     """
 
 
 # ------------------------------------------------------------------------------
-class UnitsCompatibilityError(SpectroChemPyException):
+class UnitsCompatibilityError(SpectroChemPyError):
     """
     Exception raised when units are not compatible,
     preventing some mathematical operations.
@@ -48,7 +51,7 @@ class UnitsCompatibilityError(SpectroChemPyException):
 
 
 # ------------------------------------------------------------------------------
-class DimensionsCompatibilityError(SpectroChemPyException):
+class DimensionsCompatibilityError(SpectroChemPyError):
     """
     Exception raised when dimensions are not compatible
     for concatenation for instance.
@@ -56,13 +59,13 @@ class DimensionsCompatibilityError(SpectroChemPyException):
 
 
 # ------------------------------------------------------------------------------
-class CoordinateMismatchError(SpectroChemPyException):
+class CoordinateMismatchError(SpectroChemPyError):
     """
     Exception raised when object coordinates differ.
     """
 
 
-class ProtocolError(SpectroChemPyException):
+class ProtocolError(SpectroChemPyError):
     """
     This exception is issued when a wrong protocol is secified to the
     spectrochempy importer.
@@ -110,7 +113,6 @@ def deprecated(message):
     return deprecation_decorator
 
 
-# ..............................................................................
 try:
     from contextlib import ignored
 except ImportError:
@@ -148,5 +150,11 @@ except ImportError:
             pass
 
 
+class UnknownTimeZoneError(pytz.UnknownTimeZoneError):
+    """
+    Exception raised when Timezone code is not recognized.
+    """
+
+
 # ==============================================================================
 # EOF
