@@ -1,16 +1,16 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 File utilities.
 """
-from os import environ
 import re
 import warnings
-from pathlib import Path, WindowsPath, PosixPath
+from os import environ
+from pathlib import Path, PosixPath, WindowsPath
 
 __all__ = [
     "get_filenames",
@@ -20,6 +20,7 @@ __all__ = [
     "check_filenames",
     "check_filename_to_open",
     "check_filename_to_save",
+    "download_testdata",
 ]
 
 
@@ -28,6 +29,19 @@ __all__ = [
 # ======================================================================================================================
 
 
+def download_testdata():
+    from spectrochempy.core import preferences
+    from spectrochempy.core.readers.importer import read_remote
+    from spectrochempy.utils import pathclean
+
+    datadir = pathclean(preferences.datadir)
+    # this process is relatively long, so we do not want to do it several time:
+    downloaded = datadir / "__downloaded__"
+    if not downloaded.exists():
+        read_remote(datadir, download_only=True)
+        downloaded.touch(exist_ok=True)
+
+
 def _insensitive_case_glob(pattern):
     def either(c):
         return f"[{c.lower()}{c.upper()}]" if c.isalpha() else c
@@ -87,9 +101,14 @@ def pathclean(paths):
     >>> filename.parent.name
     'irdata'
     """
-    from spectrochempy.utils import is_windows
+    import platform
+
+    def is_windows():
+        win = "Windows" in platform.platform()
+        return win
 
     def _clean(path):
+
         if isinstance(path, (Path, PosixPath, WindowsPath)):
             path = path.name
         if is_windows():
@@ -344,8 +363,8 @@ def get_filenames(*filenames, **kwargs):
     --------
     """
 
-    from spectrochempy.core import preferences as prefs
     from spectrochempy import NO_DIALOG
+    from spectrochempy.core import preferences as prefs
 
     NODIAL = (
         NO_DIALOG or "DOC_BUILDING" in environ
@@ -439,7 +458,7 @@ def get_filenames(*filenames, **kwargs):
             # we open a dialogue to select one or several files manually
             if not NODIAL:
 
-                from spectrochempy.core import open_dialog
+                from spectrochempy.core.common.dialogs import open_dialog
 
                 filenames = open_dialog(
                     single=False, directory=directory, filters=filetypes, **kwargs
@@ -455,7 +474,7 @@ def get_filenames(*filenames, **kwargs):
         else:
 
             if not NODIAL:
-                from spectrochempy.core import open_dialog
+                from spectrochempy.core.common.dialogs import open_dialog
 
                 directory = open_dialog(
                     directory=directory, filters="directory", **kwargs
@@ -551,8 +570,8 @@ def get_directory_name(directory, **kwargs):
         valid directory name.
     """
 
-    from spectrochempy.core import preferences as prefs
     from spectrochempy import NO_DIALOG
+    from spectrochempy.core import preferences as prefs
 
     data_dir = pathclean(prefs.datadir)
     working_dir = Path.cwd()
@@ -580,7 +599,7 @@ def get_directory_name(directory, **kwargs):
         # open a file dialog
         directory = data_dir
         if not NO_DIALOG:  # this is for allowing test to continue in the background
-            from spectrochempy.core import open_dialog
+            from spectrochempy.core.common.dialogs import open_dialog
 
             directory = open_dialog(
                 single=False, directory=working_dir, filters="directory", **kwargs
@@ -589,7 +608,6 @@ def get_directory_name(directory, **kwargs):
         return pathclean(directory)
 
 
-# ..............................................................................
 def check_filename_to_save(
     dataset, filename=None, save_as=False, confirm=True, **kwargs
 ):
@@ -604,7 +622,7 @@ def check_filename_to_save(
 
     if not filename or save_as or filename.exists():
 
-        from spectrochempy.core import save_dialog
+        from spectrochempy.core.common.dialogs import save_dialog
 
         # no filename provided
         open_diag = True
@@ -636,7 +654,6 @@ def check_filename_to_save(
     return pathclean(filename)
 
 
-# ..........................................................................
 def check_filename_to_open(*args, **kwargs):
     # Check the args and keywords arg to determine the correct filename
 
