@@ -1,19 +1,18 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 """
 Various methods and classes used in other part of the program.
 """
-import re
 import functools
-from datetime import datetime, timezone
-import uuid
+import re
 import types
+import uuid
 import warnings
-import textwrap
+from datetime import datetime, timezone
 
 import numpy as np
 from quaternion import as_float_array, as_quat_array
@@ -41,7 +40,7 @@ __all__ = [
     "as_quaternion",
     "quat_as_complex_array",
     "get_n_decimals",
-    "add_docstring",
+    "gt_eps",
 ]
 
 #
@@ -104,7 +103,6 @@ def _codechange(code_obj, changes):
     return code(*values)
 
 
-# ..............................................................................
 class _DummyFile(object):
     """
     A writeable object.
@@ -119,22 +117,6 @@ class _DummyFile(object):
 # ======================================================================================================================
 
 
-def add_docstring(*args):
-    """
-    Decorator which add a docstring to the actual func doctring.
-    """
-
-    def new_doc(func):
-
-        for item in args:
-            item.strip()
-
-        func.__doc__ = textwrap.dedent(func.__doc__).format(*args)
-        return func
-
-    return new_doc
-
-
 def as_quaternion(*args):
     """
     Recombine the arguments to produce a numpy array with quaternion dtype.
@@ -245,7 +227,6 @@ def dict_compare(d1, d2, check_equal_only=True):
         return True
 
 
-# ..........................................................................
 def get_component(data, select="REAL"):
     """
     Take selected components of an hypercomplex array (RRR, RIR, ...).
@@ -313,13 +294,13 @@ def get_component(data, select="REAL"):
             )
     else:
         warnings.warn(
-            f"No selection was performed because datasets with complex data have no `{select}` component. "
+            f"No selection was performed because datasets with complex data have no "
+            f"`{select}` component. "
         )
 
     return new
 
 
-# ..............................................................................
 def getdocfrom(origin):
     def decorated(func):
         func.__doc__ = origin.__doc__
@@ -334,10 +315,10 @@ def getdocfrom(origin):
     return decorated
 
 
-# ..............................................................................
 def gt_eps(arr):
     """
-    Lambda function to check that an array has at least some values greater than epsilon.
+    Lambda function to check that an array has at least some values greater than
+    epsilon.
 
     Parameters
     ----------
@@ -351,7 +332,6 @@ def gt_eps(arr):
     return np.any(arr > EPSILON)
 
 
-# ..............................................................................
 def htmldoc(text):
     """
     Format docstring in html for a nice display in IPython.
@@ -390,7 +370,6 @@ def htmldoc(text):
     return html
 
 
-# ..............................................................................
 def interleaved2complex(data):
     """
     Make a complex array from interleaved data.
@@ -398,7 +377,6 @@ def interleaved2complex(data):
     return data[..., ::2] + 1j * data[..., 1::2]
 
 
-# ..............................................................................
 def interleaved2quaternion(data):
     """
     Make a complex array from interleaved data.
@@ -406,7 +384,6 @@ def interleaved2quaternion(data):
     return data[..., ::2] + 1j * data[..., 1::2]
 
 
-# ..............................................................................
 def is_iterable(arg):
     """
     Determine if an object is iterable.
@@ -414,7 +391,6 @@ def is_iterable(arg):
     return hasattr(arg, "__iter__")
 
 
-# ..............................................................................
 def is_number(x):
     try:
         if isinstance(x, np.ndarray):
@@ -425,7 +401,6 @@ def is_number(x):
         return False
 
 
-# ..............................................................................
 def is_sequence(arg):
     """
     Determine if an object is iterable but is not a string.
@@ -433,7 +408,6 @@ def is_sequence(arg):
     return (not hasattr(arg, "strip")) and hasattr(arg, "__iter__")
 
 
-# ..............................................................................
 def largest_power_of_2(value):
     """
     Find the nearest power of two equal to or larger than a value.
@@ -452,7 +426,7 @@ def largest_power_of_2(value):
 
 
 #
-# # ..............................................................................
+#
 # def make_func_from(func, first=None):
 #     """
 #     Create a new func with its arguments from another func and a new signature.
@@ -479,7 +453,7 @@ def largest_power_of_2(value):
 #     return modified
 #
 
-# ..............................................................................
+
 def make_new_object(objtype):
     """
     Make a new object of type obj.
@@ -502,7 +476,7 @@ def make_new_object(objtype):
     return new
 
 
-# # ..............................................................................
+#
 # def makedirs(newdir):
 #     """
 #     Works the way a good mkdir should :
@@ -529,7 +503,7 @@ def make_new_object(objtype):
 #             os.mkdir(newdir)
 #
 
-# # ..............................................................................
+#
 # def makestr(li):
 #     """
 #     Make a string from a list of string.
@@ -543,7 +517,7 @@ def make_new_object(objtype):
 #     return li
 #
 
-# # ..............................................................................
+#
 # def multisort(*args, **kargs):
 #     z = list(zip(*args))
 #     z = sorted(z, key=itemgetter(kargs.get("index", 0)))
@@ -564,7 +538,7 @@ def make_new_object(objtype):
 #             return result
 
 
-# # ..............................................................................
+#
 # @contextmanager
 # def silence():
 #     """
@@ -580,10 +554,11 @@ def make_new_object(objtype):
 #     sys.stderr = old_stderr
 #
 
-# ..............................................................................
+
 def spacing_(arr):
     """
-    Return a scalar for the spacing in the one-dimensional input array (if it is uniformly spaced,
+    Return a scalar for the spacing in the one-dimensional input array
+    (if it is uniformly spaced,
     else return an array of the different spacings.
 
     Parameters
@@ -595,7 +570,8 @@ def spacing_(arr):
     out : float or array
     """
     spacings = np.diff(arr)
-    # we need to take into account only the significative digits ( but round to some decimals doesn't work
+    # we need to take into account only the significative digits
+    # ( but round to some decimals doesn't work
     # for very small number
     #    mantissa, twoexp = np.frexp(spacings)
     #    mantissa = mantissa.round(6)
@@ -611,7 +587,7 @@ def spacing_(arr):
         return spacings
 
 
-# # ..............................................................................
+#
 # def srepr(arg):
 #     if is_sequence(arg):
 #         return "<" + ", ".join(srepr(x) for x in arg) + ">"
