@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
-
-import sys
 import os
+import sys
 from pkgutil import walk_packages
 
 from traitlets import import_item
@@ -18,7 +18,7 @@ __all__ = ["list_packages", "generate_api", "get_pkg_path"]
 # PACKAGE and API UTILITIES
 # ======================================================================================================================
 
-# ..............................................................................
+
 def list_packages(package):
     """
     Return a list of the names of a package and its subpackages.
@@ -35,10 +35,9 @@ def list_packages(package):
     ):
         names.append(name)
 
-    return names
+    return sorted(names)
 
 
-# ..............................................................................
 def generate_api(api_path):
     # name of the package
 
