@@ -1,21 +1,16 @@
 # -*- coding: utf-8 -*-
-
-# ======================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory.
-# ======================================================================================================================
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 import textwrap
 
 import matplotlib as mpl
-from matplotlib import pyplot as plt
 import matplotlib.axes as maxes
 import mpl_toolkits.mplot3d.axes3d as maxes3D
-
-import plotly.graph_objects as go
 import numpy as np
-
-from spectrochempy.core.dataset.meta import Meta
-from spectrochempy.core.units import remove_args_units
+from matplotlib import pyplot as plt
 
 __all__ = [
     "cmyk2rgb",
@@ -40,6 +35,8 @@ class _Axes(maxes.Axes):
     Subclass of matplotlib Axes class
     """
 
+    from spectrochempy.core.units.units import remove_args_units
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -293,6 +290,8 @@ class _Axes(maxes.Axes):
 
 
 class _Axes3D(maxes3D.Axes3D):
+    from spectrochempy.core.units.units import remove_args_units
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -303,7 +302,7 @@ class _Axes3D(maxes3D.Axes3D):
 
 def plot_method(type, doc):
     """
-    Decorator to to select a plot method from the function name
+    Decorator to select a plot method from the function name
     """
 
     def decorator_plot_method(func):
@@ -362,7 +361,6 @@ multiplot
     return decorator_plot_method
 
 
-# ............................................................................
 # color conversion function
 def cmyk2rgb(C, M, Y, K):
     """
@@ -400,8 +398,7 @@ NBlue = cmyk2rgb(100, 30, 0, 0)
 NGreen = cmyk2rgb(85, 0, 60, 10)
 
 
-# .............................................................................
-def figure(preferences=Meta(), **kwargs):
+def figure(preferences=None, **kwargs):
     """
     Method to open a new figure.
 
@@ -412,10 +409,14 @@ def figure(preferences=Meta(), **kwargs):
     Preferences : Meta dictionary
         Per object saved plot configuration.
     """
+
+    from spectrochempy.core.common.meta import Meta
+
+    if preferences is None:
+        preferences = Meta()
     return get_figure(preferences=preferences, **kwargs)
 
 
-# .............................................................................
 def show():
     """
     Method to force the `matplotlib` figure display.
@@ -429,7 +430,6 @@ def show():
             plt.show(block=True)
 
 
-# .............................................................................
 def get_figure(**kwargs):
     """
     Get the figure where to plot.
@@ -438,7 +438,7 @@ def get_figure(**kwargs):
     ----------
     clear : bool
         If False the last used figure is returned.
-    figsize : 2-tuple of floats, default: rcParams["figure.figsize"] (default: [6.4, 4.8])
+    figsize : 2-tuple of floats, default: rcParams["figure.figsize"])
         Figure dimension (width, height) in inches.
     dpi : float, default: rcParams["figure.dpi"] (default: 100.0)
         Dots per inch.
@@ -448,13 +448,14 @@ def get_figure(**kwargs):
         The figure patch edge color.
     frameon : bool, default: preferences.figure_frameon (default: True)
         If False, suppress drawing the figure background patch.
-    tight_layout : bool or dict, default: preferences.figure.autolayout (default: False)
-        If False use subplotpars. If True adjust subplot parameters using tight_layout with default padding.
-        When providing a dict containing the keys pad, w_pad, h_pad, and rect,
-        the default tight_layout paddings will be overridden.
-    constrained_layout : bool, default: preferences.figure_constrained_layout (default: False)
+    tight_layout : bool or dict, default: preferences.figure.autolayout
+        If False use subplotpars. If True adjust subplot parameters using tight_layout
+        with default padding.nWhen providing a dict containing the keys pad, w_pad,
+        h_pad, and rect, the default tight_layout paddings will be overridden.
+    constrained_layout : bool, default: preferences.figure_constrained_layout
         If True use constrained layout to adjust positioning of plot elements.
-        Like tight_layout, but designed to be more flexible. See Constrained Layout Guide for examples.
+        Like tight_layout, but designed to be more flexible.
+        See Constrained Layout Guide for examples.
     preferences : Meta object,
         Per object plot configuration.
 
@@ -504,7 +505,8 @@ def get_figure(**kwargs):
 
 
 # FOR PLOTLY
-# .............................................................................
+
+
 def get_plotly_figure(clear=True, fig=None, **kwargs):
     """
     Get the figure where to plot.
@@ -522,6 +524,12 @@ def get_plotly_figure(clear=True, fig=None, **kwargs):
     -------
     Plotly figure instance
     """
+    from spectrochempy.utils.optional import import_optional_dependency
+
+    go = import_optional_dependency("plotly.graph_objects", errors="ignore")
+
+    if go is None:
+        raise ImportError("Plotly is not installed. Uee pip or conda to install it")
 
     if clear or fig is None:
         # create a figure
@@ -551,7 +559,6 @@ class colorscale:
 colorscale = colorscale()
 
 
-# ............................................................................
 def make_label(ss, lab="<no_axe_label>", use_mpl=True):
     """
     Make a label from title and units.
