@@ -1,4 +1,12 @@
-"""Utility functions for printing version information."""
+# -*- coding: utf-8 -*-
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
+"""
+Utility functions for printing version information.
+"""
 
 import locale
 import platform
@@ -7,18 +15,15 @@ import subprocess
 import sys
 from os import environ
 
-from spectrochempy import optional
-from spectrochempy.utils import pathclean
-
-
 __all__ = ["show_versions"]
 
-REPOS = pathclean(__file__).parent.parent.parent
 
-
-def get_sys_info():
+def _get_sys_info():
     """Returns system information as a dict"""
     # copied from XArray
+    from spectrochempy.utils import pathclean
+
+    REPOS = pathclean(__file__).parent.parent.parent
 
     blob = []
 
@@ -75,11 +80,12 @@ def show_versions(file=sys.stdout):
     file : file-like, optional
         print to the given file-like object. Defaults to sys.stdout.
     """
+    from spectrochempy.utils import optional
 
     print("\nINSTALLED VERSIONS", file=file)
     print("------------------", file=file)
 
-    for key, val in get_sys_info():
+    for key, val in _get_sys_info():
         print(f"{key}: {val}", file=file)
     print(file=file)
 
