@@ -1,11 +1,9 @@
-#  -*- coding: utf-8 -*-
-
-#  =====================================================================================================================
-#  Copyright (©) 2015-2022 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
-#  CeCILL-B FREE SOFTWARE LICENSE AGREEMENT - See full LICENSE agreement in the root directory
-#  =====================================================================================================================
-
-
+# -*- coding: utf-8 -*-
+# ======================================================================================
+# Copyright (©) 2015-2023 LCS - Laboratoire Catalyse et Spectrochimie, Caen, France.
+# CeCILL-B FREE SOFTWARE LICENSE AGREEMENT
+# See full LICENSE agreement in the root directory.
+# ======================================================================================
 __all__ = [
     "set_env",
     "assert_equal",
@@ -17,7 +15,9 @@ __all__ = [
     "assert_coord_almost_equal",
     "assert_dataset_equal",
     "assert_dataset_almost_equal",
+    "assert_equal_units",
     "assert_project_equal",
+    "assert_script_equal",
     "assert_project_almost_equal",
     "assert_approx_equal",
     "assert_raises",
@@ -26,8 +26,10 @@ __all__ = [
     "RandomSeedContext",
 ]
 
-import operator
+import contextlib
 import functools
+import operator
+import os
 import warnings
 
 import numpy as np
@@ -35,15 +37,13 @@ import numpy as np
 # import matplotlib.pyplot as plt
 # from matplotlib.testing.compare import calculate_rms, ImageAssertionError
 from numpy.testing import (
-    assert_equal,
-    assert_array_equal,
-    assert_array_almost_equal,
     assert_approx_equal,
-    assert_raises,
+    assert_array_almost_equal,
     assert_array_compare,
+    assert_array_equal,
+    assert_equal,
+    assert_raises,
 )
-import contextlib
-import os
 
 
 @contextlib.contextmanager
@@ -68,7 +68,8 @@ def set_env(**environ):
     False
 
     """
-    # https://stackoverflow.com/questions/2059482/python-temporarily-modify-the-current-processs-environment/51754362
+    # https://stackoverflow.com/questions/2059482/
+    # python-temporarily-modify-the-current-processs-environment/51754362
     old_environ = dict(os.environ)
     os.environ.update(environ)
     try:
@@ -78,12 +79,12 @@ def set_env(**environ):
         os.environ.update(old_environ)
 
 
-# ======================================================================================================================
+# ======================================================================================
 # NDDataset comparison
-# ======================================================================================================================
+# ======================================================================================
 def gisinf(x):
     # copied from numpy.testing._private.utils
-    from numpy.core import isinf, errstate
+    from numpy.core import errstate, isinf
 
     with errstate(invalid="ignore"):
         st = isinf(x)
@@ -94,9 +95,9 @@ def gisinf(x):
 
 def _compare(x, y, decimal):
     # copied from numpy.testing._private.utils
-    from numpy.core import number, float_, result_type, array
-    from numpy.core.numerictypes import issubdtype
+    from numpy.core import array, float_, number, result_type
     from numpy.core.fromnumeric import any as npany
+    from numpy.core.numerictypes import issubdtype
 
     try:
         if npany(gisinf(x)) or npany(gisinf(y)):
@@ -242,7 +243,8 @@ def compare_coords(this, other, approx=False, decimal=6, data_only=False):
         attrs = ["data"]
     else:
         attrs = ["data", "labels", "units", "meta", "title"]
-        # if 'title' in attrs:  #    attrs.remove('title')  #TODO: should we use title for comparison?
+        # if 'title' in attrs:  #    attrs.remove('title')
+        # #TODO: should we use title for comparison?
 
     if other.linear == this.linear:
         # To còmpare linear coordinates
@@ -359,7 +361,8 @@ def compare_datasets(this, other, approx=False, decimal=6, data_only=False):
     #     elif this.has_units and otherunits:
     #         eq = np.all(this._data * this._units == otherdata * otherunits)
     #     else:
-    #         raise AssertionError(f"units of {this} and {other} objects does not match")
+    #         raise AssertionError(
+    #         f"units of {this} and {other} objects does not match")
     #     return eq
 
     thistype = this.implements()
@@ -375,7 +378,7 @@ def compare_datasets(this, other, approx=False, decimal=6, data_only=False):
             "preferences",
             "description",
             "history",
-            "date",
+            "created",
             "modified",
             "origin",
             "roi",
@@ -395,7 +398,8 @@ def compare_datasets(this, other, approx=False, decimal=6, data_only=False):
                 if attr in attrs:
                     attrs.remove(attr)
 
-        # if 'title' in attrs:  #    attrs.remove('title')  #TODO: should we use title for comparison?
+        # if 'title' in attrs:  #    attrs.remove('title')
+        # #TODO: should we use title for comparison?
 
     for attr in attrs:
         if attr != "units":
@@ -485,14 +489,12 @@ def compare_datasets(this, other, approx=False, decimal=6, data_only=False):
     return True
 
 
-# ..............................................................................
 def assert_dataset_equal(nd1, nd2, **kwargs):
     kwargs["approx"] = False
     assert_dataset_almost_equal(nd1, nd2, **kwargs)
     return True
 
 
-# ..............................................................................
 def assert_dataset_almost_equal(nd1, nd2, **kwargs):
     decimal = kwargs.get("decimal", 6)
     approx = kwargs.get("approx", True)
@@ -503,14 +505,12 @@ def assert_dataset_almost_equal(nd1, nd2, **kwargs):
     return True
 
 
-# ..............................................................................
 def assert_coord_equal(nd1, nd2, **kwargs):
     kwargs["approx"] = False
     assert_coord_almost_equal(nd1, nd2, **kwargs)
     return True
 
 
-# ..............................................................................
 def assert_coord_almost_equal(nd1, nd2, **kwargs):
     decimal = kwargs.get("decimal", 6)
     approx = kwargs.get("approx", True)
@@ -521,14 +521,12 @@ def assert_coord_almost_equal(nd1, nd2, **kwargs):
     return True
 
 
-# ..............................................................................
 def assert_ndarray_equal(nd1, nd2, **kwargs):
     kwargs["approx"] = False
     assert_ndarray_almost_equal(nd1, nd2, **kwargs)
     return True
 
 
-# ..............................................................................
 def assert_ndarray_almost_equal(nd1, nd2, **kwargs):
     decimal = kwargs.get("decimal", 6)
     approx = kwargs.get("approx", True)
@@ -544,7 +542,6 @@ def assert_project_equal(proj1, proj2, **kwargs):
     return True
 
 
-# ..............................................................................
 def assert_project_almost_equal(proj1, proj2, **kwargs):
     assert len(proj1.datasets) == len(proj2.datasets)
     for nd1, nd2 in zip(proj1.datasets, proj2.datasets):
@@ -561,7 +558,6 @@ def assert_project_almost_equal(proj1, proj2, **kwargs):
     return True
 
 
-# ..............................................................................
 def assert_script_equal(sc1, sc2, **kwargs):
     if sc1 != sc2:
         raise AssertionError(f"Scripts are different: {sc1.content} != {sc2.content}")
@@ -571,7 +567,7 @@ def assert_script_equal(sc1, sc2, **kwargs):
 # RandomSeedContext
 # ======================================================================================================================
 
-# .............................................................................
+
 class RandomSeedContext(object):
     """
     A context manager (for use with the ``with`` statement) that will seed the
@@ -615,7 +611,7 @@ class RandomSeedContext(object):
 # raises and assertions (mostly copied from astropy)
 # ======================================================================================================================
 
-# .............................................................................
+
 def assert_equal_units(unit1, unit2, strict=False):
     """
     Compare units.
@@ -652,7 +648,6 @@ def _check_absorbance_related_units(unit1, unit2):
     return True
 
 
-# .............................................................................
 class raises(object):
     """
     A decorator to mark that a test should raise a given exception.
@@ -694,7 +689,6 @@ class raises(object):
         return self._ctx.__exit__(*exc_info)
 
 
-# .............................................................................
 class catch_warnings(warnings.catch_warnings):
     """
     A high-powered version of warnings.catch_warnings to use for testing
@@ -747,13 +741,13 @@ class catch_warnings(warnings.catch_warnings):
 #
 #
 # #
-# .............................................................................
+
 # def _compute_rms(x, y):
 #     return calculate_rms(x, y)
 #
 #
 # #
-# .............................................................................
+
 # def _image_compare(imgpath1, imgpath2, REDO_ON_TYPEERROR):
 #     # compare two images saved in files imgpath1 and imgpath2
 #
@@ -794,7 +788,7 @@ class catch_warnings(warnings.catch_warnings):
 #
 #
 # #
-# .............................................................................
+
 # def compare_images(imgpath1, imgpath2,
 #                    max_rms=None,
 #                    min_similarity=None, ):
@@ -821,14 +815,14 @@ class catch_warnings(warnings.catch_warnings):
 #
 #
 # #
-# .............................................................................
+
 # def same_images(imgpath1, imgpath2):
 #     if compare_images(imgpath1, imgpath2).startswith('identical'):
 #         return True
 #
 #
 # #
-# .............................................................................
+
 # def image_comparison(reference=None,
 #                      extension=None,
 #                      max_rms=None,
