@@ -32,10 +32,10 @@ Widgets for the Jupyter notebook and Jupyter lab.
 """
 from contextlib import contextmanager
 
-from IPython.core.interactiveshell import InteractiveShell
 import IPython
+from IPython.core.interactiveshell import InteractiveShell
 
-from ..utils import pathclean
+from spectrochempy.utils import pathclean
 
 __all__ = ["FileSelector"]
 
